from .proto import api_pb2 as api
import aiohttp


from .channel import Channel, Channel0, ChannelStatus
from .exceptions import GovalException, ConnectionMetadataExeption, ChannelClosed
from .client import ConnectionMetadata, Client

__all__ = (
    # pygoval.proto
    "api",
    # pygoval.client
    "ConnectionMetadata",
    "Client",
    # pygoval.channel
    "Channel",
    "Channel0",
    "ChannelStatus",
    # pygoval.exceptions
    "ChannelClosed",
    "GovalException",
    "ConnectionMetadataExeption",
)


async def fetch_token(replId: str, sid: str) -> ConnectionMetadata:
    async with aiohttp.ClientSession(
        headers={
            "X-Requested-With": "PyGoval (github.com/PotentialStyx/pygoval)",
            "User-Agent": "PyGoval (github.com/PotentialStyx/pygoval)",
            "origin": "https://replit.com",
        },
        cookies={"connect.sid": sid},
    ) as session:
        async with session.post(
            f"https://replit.com/data/repls/{replId}/get_connection_metadata"
        ) as response:
            return await response.json()



ALPHABET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"


def encode(number: int | float) -> str:
    result = ""
    number = abs(int(number))

    while number:
        number, remainder = divmod(number, 36)
        result = ALPHABET[remainder] + result

    return result or "0"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tapi.proto\x12\x03\x61pi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a google/protobuf/field_mask.proto\"\xe0=\n\x07\x43ommand\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x05\x12\x0f\n\x07session\x18\x02 \x01(\x05\x12\x0c\n\x03ref\x18\xe8\x07 \x01(\t\x12/\n\ttraceInfo\x18\xe9\x07 \x03(\x0b\x32\x1b.api.Command.TraceInfoEntry\x12$\n\x08openChan\x18\x03 \x01(\x0b\x32\x10.api.OpenChannelH\x00\x12*\n\x0bopenChanRes\x18\x04 \x01(\x0b\x32\x13.api.OpenChannelResH\x00\x12&\n\tcloseChan\x18\x05 \x01(\x0b\x32\x11.api.CloseChannelH\x00\x12,\n\x0c\x63loseChanRes\x18\x06 \x01(\x0b\x32\x14.api.CloseChannelResH\x00\x12-\n\x0e\x63ontainerState\x18\t \x01(\x0b\x32\x13.api.ContainerStateH\x00\x12!\n\x08portOpen\x18\n \x01(\x0b\x32\r.api.PortOpenH\x00\x12#\n\tportClose\x18\x30 \x01(\x0b\x32\x0e.api.PortCloseH\x00\x12\x1b\n\x05toast\x18\x0b \x01(\x0b\x32\n.api.ToastH\x00\x12+\n\rprotocolError\x18- \x01(\x0b\x32\x12.api.ProtocolErrorH\x00\x12!\n\x08redirect\x18\x0c \x01(\x0b\x32\r.api.RedirectH\x00\x12!\n\x08\x61lwaysOn\x18\r \x01(\x0b\x32\r.api.AlwaysOnH\x00\x12\x1f\n\x07runMain\x18\x10 \x01(\x0b\x32\x0c.api.RunMainH\x00\x12\x1b\n\x05\x63lear\x18\x11 \x01(\x0b\x32\n.api.ClearH\x00\x12\x0e\n\x04\x65val\x18\x14 \x01(\tH\x00\x12\x10\n\x06result\x18\x15 \x01(\tH\x00\x12\x0f\n\x05input\x18\x16 \x01(\tH\x00\x12\x10\n\x06output\x18\x17 \x01(\tH\x00\x12\x0f\n\x05\x65rror\x18\x18 \x01(\tH\x00\x12\x10\n\x06stderr\x18. \x01(\tH\x00\x12\r\n\x03log\x18/ \x01(\tH\x00\x12\x11\n\x06record\x18\xa6\x03 \x01(\tH\x00\x12!\n\x08saneTerm\x18\x1a \x01(\x0b\x32\r.api.SaneTermH\x00\x12%\n\nresizeTerm\x18\x1b \x01(\x0b\x32\x0f.api.ResizeTermH\x00\x12\x1b\n\x05state\x18\x1c \x01(\x0e\x32\n.api.StateH\x00\x12\x15\n\x02ok\x18\x1e \x01(\x0b\x32\x07.api.OKH\x00\x12\x1c\n\x07persist\x18\x1f \x01(\x0b\x32\t.api.FileH\x00\x12\"\n\rpersistMirror\x18) \x01(\x0b\x32\t.api.FileH\x00\x12\x1a\n\x05write\x18  \x01(\x0b\x32\t.api.FileH\x00\x12\x1b\n\x06remove\x18! \x01(\x0b\x32\t.api.FileH\x00\x12\x19\n\x04move\x18\" \x01(\x0b\x32\t.api.MoveH\x00\x12\x1e\n\ttryRemove\x18$ \x01(\x0b\x32\t.api.FileH\x00\x12\x1a\n\x05mkdir\x18\' \x01(\x0b\x32\t.api.FileH\x00\x12\x1a\n\x04stat\x18\xf0\x02 \x01(\x0b\x32\t.api.FileH\x00\x12#\n\x07statRes\x18\xf1\x02 \x01(\x0b\x32\x0f.api.StatResultH\x00\x12,\n\rtransferStart\x18\xc0\x02 \x01(\x0b\x32\x12.api.TransferStartH\x00\x12,\n\rtransferChunk\x18\xc1\x02 \x01(\x0b\x32\x12.api.TransferChunkH\x00\x12\x32\n\x10transferComplete\x18\xc2\x02 \x01(\x0b\x32\x15.api.TransferCompleteH\x00\x12(\n\x0etransferCancel\x18\xc3\x02 \x01(\x0b\x32\r.api.TransferH\x00\x12\"\n\x08transfer\x18\xc4\x02 \x01(\x0b\x32\r.api.TransferH\x00\x12\x19\n\x04read\x18# \x01(\x0b\x32\t.api.FileH\x00\x12\x1c\n\x07readdir\x18% \x01(\x0b\x32\t.api.FileH\x00\x12\x1b\n\x05\x66iles\x18& \x01(\x0b\x32\n.api.FilesH\x00\x12\x19\n\x04\x66ile\x18( \x01(\x0b\x32\t.api.FileH\x00\x12)\n\x0c\x63heckChanges\x18* \x01(\x0b\x32\x11.api.CheckChangesH\x00\x12\"\n\x0c\x63hangedFiles\x18+ \x01(\x0b\x32\n.api.FilesH\x00\x12\'\n\x0blintResults\x18, \x01(\x0b\x32\x10.api.LintResultsH\x00\x12.\n\x10runContainedTest\x18\x46 \x01(\x0b\x32\x12.api.ContainedTestH\x00\x12%\n\ntestResult\x18G \x01(\x0b\x32\x0f.api.TestResultH\x00\x12\x17\n\rdebuggerStart\x18Z \x01(\tH\x00\x12$\n\x0c\x64\x65\x62uggerStep\x18[ \x01(\x0b\x32\x0c.api.RunMainH\x00\x12*\n\x0e\x64\x65\x62uggerStatus\x18\\ \x01(\x0b\x32\x10.api.DebugStatusH\x00\x12-\n\x0e\x65nsurePackages\x18\x64 \x01(\x0b\x32\x13.api.EnsurePackagesH\x00\x12\x19\n\x04ping\x18x \x01(\x0b\x32\t.api.PingH\x00\x12\x19\n\x04pong\x18y \x01(\x0b\x32\t.api.PongH\x00\x12\x1b\n\x05hello\x18z \x01(\x0b\x32\n.api.HelloH\x00\x12\x1f\n\x07goodbye\x18{ \x01(\x0b\x32\x0c.api.GoodbyeH\x00\x12-\n\x0eproxyGoingAway\x18| \x01(\x0b\x32\x13.api.ProxyGoingAwayH\x00\x12\x1a\n\x04hint\x18\x82\x01 \x01(\x0b\x32\t.api.HintH\x00\x12 \n\x07\x63onnect\x18\x96\x01 \x01(\x0b\x32\x0c.api.ConnectH\x00\x12\x1a\n\x04send\x18\x97\x01 \x01(\x0b\x32\t.api.SendH\x00\x12\x1a\n\x04recv\x18\x98\x01 \x01(\x0b\x32\t.api.RecvH\x00\x12&\n\ndisconnect\x18\x99\x01 \x01(\x0b\x32\x0f.api.DisconnectH\x00\x12(\n\x0b\x66ileAuthReq\x18\xc8\x01 \x01(\x0b\x32\x10.api.FileAuthReqH\x00\x12(\n\x0b\x66ileAuthRes\x18\xc9\x01 \x01(\x0b\x32\x10.api.FileAuthResH\x00\x12\x32\n\x10mutliFileAuthRes\x18\xca\x01 \x01(\x0b\x32\x15.api.MultiFileAuthResH\x00\x12(\n\x0blistObjects\x18\xcd\x01 \x01(\x0b\x32\x10.api.ListObjectsH\x00\x12\x30\n\x0flistObjectsResp\x18\xce\x01 \x01(\x0b\x32\x14.api.ListObjectsRespH\x00\x12\x1c\n\x02ot\x18\xdc\x01 \x01(\x0b\x32\r.api.OTPacketH\x00\x12\"\n\x08otstatus\x18\xdd\x01 \x01(\x0b\x32\r.api.OTStatusH\x00\x12&\n\notLinkFile\x18\xde\x01 \x01(\x0b\x32\x0f.api.OTLinkFileH\x00\x12\x36\n\x12otLinkFileResponse\x18\xe5\x01 \x01(\x0b\x32\x17.api.OTLinkFileResponseH\x00\x12%\n\x0botNewCursor\x18\xdf\x01 \x01(\x0b\x32\r.api.OTCursorH\x00\x12(\n\x0eotDeleteCursor\x18\xe0\x01 \x01(\x0b\x32\r.api.OTCursorH\x00\x12.\n\x0eotFetchRequest\x18\xe1\x01 \x01(\x0b\x32\x13.api.OTFetchRequestH\x00\x12\x30\n\x0fotFetchResponse\x18\xe2\x01 \x01(\x0b\x32\x14.api.OTFetchResponseH\x00\x12H\n\x1botTransformSelectionRequest\x18\xe3\x01 \x01(\x0b\x32 .api.OTTransformSelectionRequestH\x00\x12J\n\x1cotTransformSelectionResponse\x18\xe4\x01 \x01(\x0b\x32!.api.OTTransformSelectionResponseH\x00\x12\x1c\n\x05\x66lush\x18\xfb\x01 \x01(\x0b\x32\n.api.FlushH\x00\x12\x1c\n\x05\x64\x65\x62ug\x18\xe6\x01 \x01(\x0b\x32\n.api.DebugH\x00\x12\"\n\x08startVCR\x18\xe7\x01 \x01(\x0b\x32\r.api.StartVCRH\x00\x12 \n\x07readVCR\x18\xe8\x01 \x01(\x0b\x32\x0c.api.ReadVCRH\x00\x12\x1e\n\x06VCRLog\x18\xe9\x01 \x01(\x0b\x32\x0b.api.VCRLogH\x00\x12\x1a\n\x04\x61uth\x18\xeb\x01 \x01(\x0b\x32\t.api.AuthH\x00\x12\"\n\x08\x65xecInfo\x18\xf0\x01 \x01(\x0b\x32\r.api.ExecInfoH\x00\x12,\n\rsubscribeFile\x18\x80\x02 \x01(\x0b\x32\x12.api.SubscribeFileH\x00\x12$\n\tfileEvent\x18\x81\x02 \x01(\x0b\x32\x0e.api.FileEventH\x00\x12\x1e\n\x06roster\x18\x84\x02 \x01(\x0b\x32\x0b.api.RosterH\x00\x12\x1a\n\x04join\x18\x85\x02 \x01(\x0b\x32\t.api.UserH\x00\x12\x1a\n\x04part\x18\x86\x02 \x01(\x0b\x32\t.api.UserH\x00\x12\"\n\x08openFile\x18\x87\x02 \x01(\x0b\x32\r.api.OpenFileH\x00\x12&\n\nfileOpened\x18\x88\x02 \x01(\x0b\x32\x0f.api.FileOpenedH\x00\x12&\n\nfollowUser\x18\x89\x02 \x01(\x0b\x32\x0f.api.FollowUserH\x00\x12*\n\x0cunfollowUser\x18\x8c\x02 \x01(\x0b\x32\x11.api.UnfollowUserH\x00\x12>\n\x16updateSessionTimestamp\x18\x8a\x02 \x01(\x0b\x32\x1b.api.UpdateSessionTimestampH\x00\x12@\n\x17sessionTimestampUpdated\x18\x8b\x02 \x01(\x0b\x32\x1c.api.SessionTimestampUpdatedH\x00\x12\x1a\n\x04\x65xec\x18\x8e\x02 \x01(\x0b\x32\t.api.ExecH\x00\x12,\n\rpackageSearch\x18\x98\x02 \x01(\x0b\x32\x12.api.PackageSearchH\x00\x12\x34\n\x11packageSearchResp\x18\x99\x02 \x01(\x0b\x32\x16.api.PackageSearchRespH\x00\x12(\n\x0bpackageInfo\x18\x9a\x02 \x01(\x0b\x32\x10.api.PackageInfoH\x00\x12\x30\n\x0fpackageInfoResp\x18\x9b\x02 \x01(\x0b\x32\x14.api.PackageInfoRespH\x00\x12&\n\npackageAdd\x18\x9c\x02 \x01(\x0b\x32\x0f.api.PackageAddH\x00\x12,\n\rpackageRemove\x18\x9d\x02 \x01(\x0b\x32\x12.api.PackageRemoveH\x00\x12.\n\x0epackageInstall\x18\x9e\x02 \x01(\x0b\x32\x13.api.PackageInstallH\x00\x12\x38\n\x13packageListSpecfile\x18\x9f\x02 \x01(\x0b\x32\x18.api.PackageListSpecfileH\x00\x12@\n\x17packageListSpecfileResp\x18\xa0\x02 \x01(\x0b\x32\x1c.api.PackageListSpecfileRespH\x00\x12\x32\n\x10packageCacheSave\x18\xa1\x02 \x01(\x0b\x32\x15.api.PackageCacheSaveH\x00\x12(\n\x0b\x63hatMessage\x18\xb6\x02 \x01(\x0b\x32\x10.api.ChatMessageH\x00\x12&\n\nchatTyping\x18\xb7\x02 \x01(\x0b\x32\x0f.api.ChatTypingH\x00\x12.\n\x0e\x63hatScrollback\x18\xb8\x02 \x01(\x0b\x32\x13.api.ChatScrollbackH\x00\x12&\n\nfsSnapshot\x18\xca\x02 \x01(\x0b\x32\x0f.api.FSSnapshotH\x00\x12\x30\n\x0f\x66sSnapshotEvent\x18\x84\x03 \x01(\x0b\x32\x14.api.FSSnapshotEventH\x00\x12\"\n\nfsTakeLock\x18\xcb\x02 \x01(\x0b\x32\x0b.api.FSLockH\x00\x12%\n\rfsReleaseLock\x18\xcc\x02 \x01(\x0b\x32\x0b.api.FSLockH\x00\x12\x11\n\x06hasCap\x18\xcf\x02 \x01(\x08H\x00\x12,\n\rsnapshotEvent\x18\x85\x03 \x01(\x0b\x32\x12.api.SnapshotEventH\x00\x12&\n\x1bNoninteractiveFSChangeEvent\x18\x88\x03 \x01(\x08H\x00\x12&\n\npid1Config\x18\xd4\x02 \x01(\x0b\x32\x0f.api.Pid1ConfigH\x00\x12 \n\x07metrics\x18\xde\x02 \x01(\x0b\x32\x0c.api.MetricsH\x00\x12&\n\nbootStatus\x18\xdf\x02 \x01(\x0b\x32\x0f.api.BootStatusH\x00\x12\x30\n\x0freadMetaRequest\x18\xe8\x02 \x01(\x0b\x32\x14.api.ReadMetaRequestH\x00\x12\x32\n\x10readMetaResponse\x18\x80\x03 \x01(\x0b\x32\x15.api.ReadMetaResponseH\x00\x12\x32\n\x10writeMetaRequest\x18\xe9\x02 \x01(\x0b\x32\x15.api.WriteMetaRequestH\x00\x12\x34\n\x11writeMetaResponse\x18\x81\x03 \x01(\x0b\x32\x16.api.WriteMetaResponseH\x00\x12\x34\n\x11\x61ppendMetaRequest\x18\xea\x02 \x01(\x0b\x32\x16.api.AppendMetaRequestH\x00\x12\x36\n\x12\x61ppendMetaResponse\x18\x82\x03 \x01(\x0b\x32\x17.api.AppendMetaResponseH\x00\x12\x1c\n\x05\x61udio\x18\xeb\x02 \x01(\x0b\x32\n.api.AudioH\x00\x12*\n\x0cpprofRequest\x18\xec\x02 \x01(\x0b\x32\x11.api.PprofRequestH\x00\x12,\n\rpprofResponse\x18\xed\x02 \x01(\x0b\x32\x12.api.PprofResponseH\x00\x12\x1e\n\x06\x61udio2\x18\xee\x02 \x01(\x0b\x32\x0b.api.Audio2H\x00\x12$\n\tPTYConfig\x18\xef\x02 \x01(\x0b\x32\x0e.api.PTYConfigH\x00\x12$\n\tdebugMain\x18\xf2\x02 \x01(\x0b\x32\x0e.api.DebugMainH\x00\x12&\n\ndebugState\x18\xf3\x02 \x01(\x0b\x32\x0f.api.DebugStateH\x00\x12.\n\x0e\x64\x65\x62ugMainReply\x18\xf4\x02 \x01(\x0b\x32\x13.api.DebugMainReplyH\x00\x12&\n\ndebugInput\x18\xf5\x02 \x01(\x0b\x32\x0f.api.DebugInputH\x00\x12(\n\x0b\x64\x65\x62ugOutput\x18\xf6\x02 \x01(\x0b\x32\x10.api.DebugOutputH\x00\x12$\n\tdebugStop\x18\xf7\x02 \x01(\x0b\x32\x0e.api.DebugStopH\x00\x12&\n\ndebugLeave\x18\xf8\x02 \x01(\x0b\x32\x0f.api.DebugLeaveH\x00\x12,\n\rdebugSessions\x18\xf9\x02 \x01(\x0b\x32\x12.api.DebugSessionsH\x00\x12\x44\n\x19\x64\x65\x62ugAddBreakpointRequest\x18\xfc\x02 \x01(\x0b\x32\x1e.api.DebugAddBreakpointRequestH\x00\x12J\n\x1c\x64\x65\x62ugUpdateBreakpointRequest\x18\x83\x03 \x01(\x0b\x32!.api.DebugUpdateBreakpointRequestH\x00\x12J\n\x1c\x64\x65\x62ugRemoveBreakpointRequest\x18\xfd\x02 \x01(\x0b\x32!.api.DebugRemoveBreakpointRequestH\x00\x12:\n\x14\x64\x65\x62ugBreakpointEvent\x18\xff\x02 \x01(\x0b\x32\x19.api.DebugBreakpointEventH\x00\x12\x38\n\x13\x64otReplitGetRequest\x18\xfa\x02 \x01(\x0b\x32\x18.api.DotReplitGetRequestH\x00\x12:\n\x14\x64otReplitGetResponse\x18\xfb\x02 \x01(\x0b\x32\x19.api.DotReplitGetResponseH\x00\x12\x38\n\x13runConfigGetRequest\x18\x86\x03 \x01(\x0b\x32\x18.api.RunConfigGetRequestH\x00\x12:\n\x14runConfigGetResponse\x18\x87\x03 \x01(\x0b\x32\x19.api.RunConfigGetResponseH\x00\x12>\n\x16\x64otReplitUpdateRequest\x18\x8b\x03 \x01(\x0b\x32\x1b.api.DotReplitUpdateRequestH\x00\x12@\n\x17\x64otReplitUpdateResponse\x18\x8c\x03 \x01(\x0b\x32\x1c.api.DotReplitUpdateResponseH\x00\x12\"\n\x08startLSP\x18\xd9\x02 \x01(\x0b\x32\r.api.StartLSPH\x00\x12.\n\x0e\x66irewallDenied\x18\x89\x03 \x01(\x0b\x32\x13.api.FirewallDeniedH\x00\x12:\n\x14nixPackageAddRequest\x18\x9a\x03 \x01(\x0b\x32\x19.api.NixPackageAddRequestH\x00\x12<\n\x15nixPackageAddResponse\x18\x9b\x03 \x01(\x0b\x32\x1a.api.NixPackageAddResponseH\x00\x12@\n\x17nixPackageRemoveRequest\x18\x9c\x03 \x01(\x0b\x32\x1c.api.NixPackageRemoveRequestH\x00\x12\x42\n\x18nixPackageRemoveResponse\x18\x9d\x03 \x01(\x0b\x32\x1d.api.NixPackageRemoveResponseH\x00\x12<\n\x15nixPackageListRequest\x18\x9e\x03 \x01(\x0b\x32\x1a.api.NixPackageListRequestH\x00\x12>\n\x16nixPackageListResponse\x18\x9f\x03 \x01(\x0b\x32\x1b.api.NixPackageListResponseH\x00\x12\x36\n\x12nixChannelsRequest\x18\xa0\x03 \x01(\x0b\x32\x17.api.NixChannelsRequestH\x00\x12\x38\n\x13nixChannelsResponse\x18\xa1\x03 \x01(\x0b\x32\x18.api.NixChannelsResponseH\x00\x12L\n\x1dnixChannelLatestStableRequest\x18\xa2\x03 \x01(\x0b\x32\".api.NixChannelLatestStableRequestH\x00\x12N\n\x1enixChannelLatestStableResponse\x18\xa3\x03 \x01(\x0b\x32#.api.NixChannelLatestStableResponseH\x00\x12@\n\x17nixPackageSearchRequest\x18\xa4\x03 \x01(\x0b\x32\x1c.api.NixPackageSearchRequestH\x00\x12\x42\n\x18nixPackageSearchResponse\x18\xa5\x03 \x01(\x0b\x32\x1d.api.NixPackageSearchResponseH\x00\x12$\n\tuserEvent\x18\xa7\x03 \x01(\x0b\x32\x0e.api.UserEventH\x00\x12:\n\x14replspaceApiOpenFile\x18\xa8\x03 \x01(\x0b\x32\x19.api.ReplspaceApiOpenFileH\x00\x12<\n\x15replspaceApiCloseFile\x18\xa9\x03 \x01(\x0b\x32\x1a.api.ReplspaceApiCloseFileH\x00\x12\x46\n\x1areplspaceApiGetGitHubToken\x18\xaa\x03 \x01(\x0b\x32\x1f.api.ReplspaceApiGetGitHubTokenH\x00\x12@\n\x17replspaceApiGitHubToken\x18\xab\x03 \x01(\x0b\x32\x1c.api.ReplspaceApiGitHubTokenH\x00\x12 \n\x07\x66ocused\x18\xac\x03 \x01(\x0b\x32\x0c.api.FocusedH\x00\x12:\n\x14nixModulesGetRequest\x18\xad\x03 \x01(\x0b\x32\x19.api.NixModulesGetRequestH\x00\x12<\n\x15nixModulesGetResponse\x18\xae\x03 \x01(\x0b\x32\x1a.api.NixModulesGetResponseH\x00\x12\x34\n\x11nixModulesChanged\x18\xaf\x03 \x01(\x0b\x32\x16.api.NixModulesChangedH\x00\x12>\n\x16nixModulesBuildRequest\x18\xb0\x03 \x01(\x0b\x32\x1b.api.NixModulesBuildRequestH\x00\x12\x44\n\x19packageSetPackagerRequest\x18\xb1\x03 \x01(\x0b\x32\x1e.api.PackageSetPackagerRequestH\x00\x12\x42\n\x16packageSetPackagerResp\x18\xb2\x03 \x01(\x0b\x32\x1f.api.PackageSetPackagerResponseH\x00\x12\x38\n\x13toolchainGetRequest\x18\xb3\x03 \x01(\x0b\x32\x18.api.ToolchainGetRequestH\x00\x12:\n\x14toolchainGetResponse\x18\xb4\x03 \x01(\x0b\x32\x19.api.ToolchainGetResponseH\x00\x12\x32\n\x10toolchainChanged\x18\xb5\x03 \x01(\x0b\x32\x15.api.ToolchainChangedH\x00\x1a\x30\n\x0eTraceInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x62ody\"(\n\x14NixPackageAddRequest\x12\x10\n\x08packages\x18\x01 \x03(\t\"\x17\n\x15NixPackageAddResponse\"+\n\x17NixPackageRemoveRequest\x12\x10\n\x08packages\x18\x01 \x03(\t\"\x1a\n\x18NixPackageRemoveResponse\"\x17\n\x15NixPackageListRequest\";\n\x16NixPackageListResponse\x12!\n\x08packages\x18\x01 \x03(\x0b\x32\x0f.api.NixPackage\"|\n\nNixPackage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x13\n\x0bhomepageURL\x18\x04 \x03(\t\x12\x13\n\x0bmaintainers\x18\x05 \x03(\t\x12\x10\n\x08licenses\x18\x06 \x03(\t\"\x14\n\x12NixChannelsRequest\"\'\n\x13NixChannelsResponse\x12\x10\n\x08\x63hannels\x18\x01 \x03(\t\"\x1f\n\x1dNixChannelLatestStableRequest\"1\n\x1eNixChannelLatestStableResponse\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\"(\n\x17NixPackageSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\"=\n\x18NixPackageSearchResponse\x12!\n\x08packages\x18\x01 \x03(\x0b\x32\x0f.api.NixPackage\"6\n\x08StartLSP\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x18\n\x10languageServerId\x18\x02 \x01(\t\"\x15\n\x05\x41udio\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"\'\n\x06\x41udio2\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x11\x12\x0f\n\x07samples\x18\x02 \x01(\x03\"Q\n\rPreconditions\x12\x12\n\ngeneration\x18\x01 \x01(\x03\x12\x16\n\x0emetageneration\x18\x02 \x01(\x03\x12\x14\n\x0c\x64oesNotExist\x18\x03 \x01(\x08\"<\n\x0fReadMetaRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06\x65xists\x18\x02 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"i\n\x10ReadMetaResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06\x65xists\x18\x02 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x12\n\ngeneration\x18\x04 \x01(\x03\x12\x16\n\x0emetageneration\x18\x05 \x01(\x03\"X\n\x10WriteMetaRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12)\n\rpreconditions\x18\x05 \x01(\x0b\x32\x12.api.Preconditions\"?\n\x11WriteMetaResponse\x12\x12\n\ngeneration\x18\x01 \x01(\x03\x12\x16\n\x0emetageneration\x18\x02 \x01(\x03\"Y\n\x11\x41ppendMetaRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12)\n\rpreconditions\x18\x05 \x01(\x0b\x32\x12.api.Preconditions\"@\n\x12\x41ppendMetaResponse\x12\x12\n\ngeneration\x18\x01 \x01(\x03\x12\x16\n\x0emetageneration\x18\x02 \x01(\x03\"\xd3\x01\n\nBootStatus\x12$\n\x05stage\x18\x01 \x01(\x0e\x32\x15.api.BootStatus.Stage\x12\x10\n\x08progress\x18\x02 \x01(\r\x12\r\n\x05total\x18\x03 \x01(\r\"~\n\x05Stage\x12\r\n\tHANDSHAKE\x10\x00\x12\r\n\tACQUIRING\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05PROXY\x10\x05\x12\x0e\n\nPULL_FILES\x10\x06\x12\x0e\n\nLOAD_BLOCK\x10\x07\x12\x13\n\x0f\x42LOCK_MIGRATION\x10\t\x12\t\n\x05RETRY\x10\x08\"\xaf\x01\n\nPid1Config\x12\x0b\n\x03\x63wd\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12%\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x18.api.Pid1Config.EnvEntry\x12\x0f\n\x07noStore\x18\x04 \x01(\x08\x12\x1e\n\x16noninteractiveFSChange\x18\x05 \x01(\x08\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x16\n\x06\x46SLock\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x0c\n\nFSSnapshot\"\"\n\x0f\x46SSnapshotEvent\x12\x0f\n\x07sources\x18\x01 \x03(\t\" \n\rSnapshotEvent\x12\x0f\n\x07sources\x18\x01 \x03(\t\")\n\rSubscribeFile\x12\x18\n\x05\x66iles\x18\x01 \x03(\x0b\x32\t.api.File\"\x90\x01\n\tFileEvent\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12\x17\n\x04\x64\x65st\x18\x03 \x01(\x0b\x32\t.api.File\x12\x1d\n\x02op\x18\x02 \x01(\x0e\x32\x11.api.FileEvent.Op\"2\n\x02Op\x12\n\n\x06\x43reate\x10\x00\x12\x08\n\x04Move\x10\x01\x12\n\n\x06Remove\x10\x02\x12\n\n\x06Modify\x10\x03\"c\n\x05\x46lush\x12+\n\x0b\x63onsistency\x18\x01 \x01(\x0e\x32\x16.api.Flush.Consistency\"-\n\x0b\x43onsistency\x12\x14\n\x10PermanentStorage\x10\x00\x12\x08\n\x04\x44isk\x10\x01\"Z\n\nOTLinkFile\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12\x17\n\x0fhighConsistency\x18\x02 \x01(\x08\x12\x1a\n\x12OBSOLETEUseModTime\x18\x03 \x01(\x08\"D\n\x12OTLinkFileResponse\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x1d\n\nlinkedFile\x18\x02 \x01(\x0b\x32\t.api.File\"*\n\x04\x41uth\x12\r\n\x05token\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontainerID\x18\x02 \x01(\t\"\xa3\x01\n\x08VCREntry\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12*\n\tdirection\x18\x02 \x01(\x0e\x32\x17.api.VCREntry.Direction\x12\x1d\n\x07\x63ommand\x18\x03 \x01(\x0b\x32\x0c.api.Command\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x0e\n\x06replid\x18\x05 \x01(\t\"\x1c\n\tDirection\x12\x06\n\x02IN\x10\x00\x12\x07\n\x03OUT\x10\x01\"\n\n\x08StartVCR\"\t\n\x07ReadVCR\"@\n\x06VCRLog\x12\x1a\n\x03log\x18\x01 \x03(\x0b\x32\r.api.VCREntry\x12\x1a\n\x07logfile\x18\x02 \x01(\x0b\x32\t.api.File\"+\n\x08\x45xecInfo\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x15\n\x05\x44\x65\x62ug\x12\x0c\n\x04text\x18\x01 \x01(\t\"K\n\x0b\x46ileAuthReq\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12#\n\x06method\x18\x02 \x01(\x0e\x32\x13.api.FileAuthMethod\"o\n\x10MultiFileAuthRes\x12\x1d\n\x03put\x18\x01 \x01(\x0b\x32\x10.api.FileAuthRes\x12\x1d\n\x03\x64\x65l\x18\x02 \x01(\x0b\x32\x10.api.FileAuthRes\x12\x1d\n\x03get\x18\x03 \x01(\x0b\x32\x10.api.FileAuthRes\"\x8a\x01\n\x0b\x46ileAuthRes\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12\x0b\n\x03url\x18\x02 \x01(\t\x12#\n\x06method\x18\x03 \x01(\x0e\x32\x13.api.FileAuthMethod\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\x12\r\n\x05\x65rror\x18\x05 \x01(\t\x12\x11\n\treplError\x18\x07 \x01(\x08\"\x1d\n\x0bListObjects\x12\x0e\n\x06prefix\x18\x01 \x01(\t\"\"\n\x0fListObjectsResp\x12\x0f\n\x07objects\x18\x01 \x03(\t\"\x1b\n\nDisconnect\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x14\n\x04Send\x12\x0c\n\x04\x62uff\x18\x01 \x01(\x0c\"\x14\n\x04Recv\x12\x0c\n\x04\x62uff\x18\x01 \x01(\x0c\"&\n\x07\x43onnect\x12\r\n\x05proto\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\t\"\x14\n\x04Hint\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x06\n\x04Ping\"\x06\n\x04Pong\"8\n\x05Hello\x12\x0e\n\x06userid\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\"\t\n\x07Goodbye\"\x0e\n\x0c\x43heckChanges\":\n\x0e\x45nsurePackages\x12\x0f\n\x07install\x18\x01 \x01(\x08\x12\x17\n\x04\x66ile\x18\x02 \x01(\x0b\x32\t.api.File\"\x07\n\x05Start\";\n\x0b\x44\x65\x62ugStatus\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12\x1e\n\x05stack\x18\x02 \x03(\x0b\x32\x0f.api.StackFrame\",\n\nStackFrame\x12\x10\n\x08\x66unction\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\r\"E\n\rContainedTest\x12\x18\n\x05suite\x18\x01 \x01(\x0b\x32\t.api.File\x12\x1a\n\x07project\x18\x02 \x03(\x0b\x32\t.api.File\"M\n\nTestResult\x12\x0e\n\x06passed\x18\x01 \x01(\x08\x12\x0e\n\x06stderr\x18\x02 \x01(\t\x12\x1f\n\x05\x66\x61ils\x18\x03 \x03(\x0b\x32\x10.api.TestFailure\"*\n\x0bTestFailure\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05trace\x18\x02 \x01(\t\"(\n\nResizeTerm\x12\x0c\n\x04rows\x18\x01 \x01(\r\x12\x0c\n\x04\x63ols\x18\x02 \x01(\r\"\n\n\x08SaneTerm\"/\n\x0bLintResults\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.api.LintResult\"E\n\nLintResult\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03row\x18\x02 \x01(\x05\x12\x0e\n\x06\x63olumn\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\t\"\x04\n\x02OK\"(\n\x04Move\x12\x0f\n\x07oldPath\x18\x01 \x01(\t\x12\x0f\n\x07newPath\x18\x02 \x01(\t\"!\n\x05\x46iles\x12\x18\n\x05\x66iles\x18\x01 \x03(\x0b\x32\t.api.File\"k\n\nStatResult\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.api.File.Type\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\x10\n\x08\x66ileMode\x18\x04 \x01(\t\x12\x0f\n\x07modTime\x18\x05 \x01(\x03\"g\n\x04\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.api.File.Type\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"\"\n\x04Type\x12\x0b\n\x07REGULAR\x10\x00\x12\r\n\tDIRECTORY\x10\x01\"\x16\n\x08Transfer\x12\n\n\x02id\x18\x01 \x01(\t\"+\n\rTransferStart\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x03\",\n\rTransferChunk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"-\n\x10TransferComplete\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x63rc32\x18\x02 \x01(\r\"\x07\n\x05\x43lear\"\x15\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1d\n\rProtocolError\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x17\n\x08Redirect\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x1a\n\x08\x41lwaysOn\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"\x88\x01\n\x07RunMain\x12%\n\x07runMode\x18\x01 \x01(\x0e\x32\x14.api.RunMain.RunMode\x12\x12\n\nidempotent\x18\x02 \x01(\x08\x12\x10\n\x08\x66ilePath\x18\x03 \x01(\t\x12\x10\n\x08runnerId\x18\x04 \x01(\t\"\x1e\n\x07RunMode\x12\x07\n\x03RUN\x10\x00\x12\n\n\x06RECORD\x10\x01\"\x99\x01\n\x0bOpenChannel\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x17.api.OpenChannel.Action\x12\n\n\x02id\x18\x04 \x01(\x05\"6\n\x06\x41\x63tion\x12\n\n\x06\x43REATE\x10\x00\x12\n\n\x06\x41TTACH\x10\x01\x12\x14\n\x10\x41TTACH_OR_CREATE\x10\x02\"\x84\x01\n\x0eOpenChannelRes\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.api.OpenChannelRes.State\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"-\n\x05State\x12\x0b\n\x07\x43REATED\x10\x00\x12\x0c\n\x08\x41TTACHED\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"x\n\x0c\x43loseChannel\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x18.api.CloseChannel.Action\"2\n\x06\x41\x63tion\x12\x0e\n\nDISCONNECT\x10\x00\x12\r\n\tTRY_CLOSE\x10\x01\x12\t\n\x05\x43LOSE\x10\x02\"|\n\x0f\x43loseChannelRes\x12\n\n\x02id\x18\x01 \x01(\x05\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.api.CloseChannelRes.Status\"0\n\x06Status\x12\x0e\n\nDISCONNECT\x10\x00\x12\t\n\x05\x43LOSE\x10\x01\x12\x0b\n\x07NOTHING\x10\x02\"Y\n\x0e\x43ontainerState\x12(\n\x05state\x18\x01 \x01(\x0e\x32\x19.api.ContainerState.State\"\x1d\n\x05State\x12\t\n\x05SLEEP\x10\x00\x12\t\n\x05READY\x10\x01\"R\n\x08PortOpen\x12\x11\n\tforwarded\x18\x01 \x01(\x08\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x14\n\x0c\x65xternalPort\x18\x04 \x01(\r\"@\n\tPortClose\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x14\n\x0c\x65xternalPort\x18\x04 \x01(\r\"8\n\x0eOTFetchRequest\x12\x13\n\x0bversionFrom\x18\x01 \x01(\r\x12\x11\n\tversionTo\x18\x02 \x01(\r\"1\n\x0fOTFetchResponse\x12\x1e\n\x07packets\x18\x01 \x03(\x0b\x32\r.api.OTPacket\"k\n\x1bOTTransformSelectionRequest\x12\x12\n\nindexStart\x18\x01 \x01(\r\x12\x10\n\x08indexEnd\x18\x02 \x01(\r\x12\x13\n\x0bversionFrom\x18\x03 \x01(\r\x12\x11\n\tversionTo\x18\x04 \x01(\r\"U\n\x1cOTTransformSelectionResponse\x12\x12\n\nindexStart\x18\x01 \x01(\r\x12\x10\n\x08indexEnd\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\r\"\xfa\x01\n\x08OTPacket\x12\x15\n\rspookyVersion\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x1e\n\x02op\x18\x02 \x03(\x0b\x32\x12.api.OTOpComponent\x12\r\n\x05\x63rc32\x18\x03 \x01(\r\x12-\n\tcommitted\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05nonce\x18\x06 \x01(\r\x12\x0e\n\x06userId\x18\x07 \x01(\r\x12$\n\x06\x61uthor\x18\x08 \x01(\x0e\x32\x14.api.OTPacket.Author\"#\n\x06\x41uthor\x12\x08\n\x04USER\x10\x00\x12\x0f\n\x0bGHOSTWRITER\x10\x01\"R\n\rOTOpComponent\x12\x0e\n\x04skip\x18\x01 \x01(\rH\x00\x12\x10\n\x06\x64\x65lete\x18\x02 \x01(\rH\x00\x12\x10\n\x06insert\x18\x03 \x01(\tH\x00\x42\r\n\x0bopComponent\"l\n\x08OTStatus\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x1d\n\nlinkedFile\x18\x03 \x01(\x0b\x32\t.api.File\x12\x1e\n\x07\x63ursors\x18\x04 \x03(\x0b\x32\r.api.OTCursor\"o\n\x08OTCursor\x12\x10\n\x08position\x18\x01 \x01(\r\x12\x16\n\x0eselectionStart\x18\x02 \x01(\r\x12\x14\n\x0cselectionEnd\x18\x03 \x01(\r\x12\x17\n\x04user\x18\x04 \x01(\x0b\x32\t.api.User\x12\n\n\x02id\x18\x05 \x01(\t\"-\n\x0b\x43hatMessage\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\".\n\nChatTyping\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0e\n\x06typing\x18\x02 \x01(\x08\"\x7f\n\x04User\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05roles\x18\x03 \x03(\t\x12\x0f\n\x07session\x18\x04 \x01(\x05\x12\r\n\x05teams\x18\x05 \x03(\t\x12\x0b\n\x03\x62io\x18\x06 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\x12\x14\n\x0cprofileImage\x18\x08 \x01(\t\"A\n\x06Roster\x12\x17\n\x04user\x18\x01 \x03(\x0b\x32\t.api.User\x12\x1e\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x0f.api.FileOpened\"\x18\n\x08OpenFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"j\n\nFileOpened\x12\x0e\n\x06userId\x18\x01 \x01(\r\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0f\n\x07session\x18\x03 \x01(\x05\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"I\n\x14ReplspaceApiOpenFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x14\n\x0cwaitForClose\x18\x02 \x01(\x08\x12\r\n\x05nonce\x18\x03 \x01(\t\"4\n\x15ReplspaceApiCloseFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\"+\n\x1aReplspaceApiGetGitHubToken\x12\r\n\x05nonce\x18\x01 \x01(\t\"7\n\x17ReplspaceApiGitHubToken\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"\t\n\x07\x46ocused\"\x18\n\x16UpdateSessionTimestamp\"Y\n\x17SessionTimestampUpdated\x12\x0f\n\x07session\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1d\n\nFollowUser\x12\x0f\n\x07session\x18\x01 \x01(\x05\"\x1f\n\x0cUnfollowUser\x12\x0f\n\x07session\x18\x01 \x01(\x05\"\xfb\x01\n\x04\x45xec\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x1f\n\x03\x65nv\x18\x02 \x03(\x0b\x32\x12.api.Exec.EnvEntry\x12\x10\n\x08\x62locking\x18\x03 \x01(\x08\x12&\n\tlifecycle\x18\x06 \x01(\x0e\x32\x13.api.Exec.Lifecycle\x12\x13\n\x0bsplitStderr\x18\x04 \x01(\x08\x12\x11\n\tsplitLogs\x18\x05 \x01(\x08\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\tLifecycle\x12\x10\n\x0cNON_BLOCKING\x10\x00\x12\x0c\n\x08\x42LOCKING\x10\x01\x12\t\n\x05STDIN\x10\x02\"\xed\x01\n\x07Package\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04spec\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x13\n\x0bhomepageURL\x18\x0c \x01(\t\x12\x18\n\x10\x64ocumentationURL\x18\r \x01(\t\x12\x15\n\rsourceCodeURL\x18\x0e \x01(\t\x12\x15\n\rbugTrackerURL\x18\x0f \x01(\t\x12\x0e\n\x06\x61uthor\x18\x10 \x01(\t\x12\x0f\n\x07license\x18\x11 \x01(\t\x12\"\n\x0c\x64\x65pendencies\x18\x12 \x03(\x0b\x32\x0c.api.Package\"/\n\x19PackageSetPackagerRequest\x12\x12\n\npackagerId\x18\x01 \x01(\t\"0\n\x1aPackageSetPackagerResponse\x12\x12\n\npackagerId\x18\x01 \x01(\t\"\x1e\n\rPackageSearch\x12\r\n\x05query\x18\x01 \x01(\t\"2\n\x11PackageSearchResp\x12\x1d\n\x07results\x18\x01 \x03(\x0b\x32\x0c.api.Package\"(\n\x0bPackageInfo\x12\x19\n\x03pkg\x18\x01 \x01(\x0b\x32\x0c.api.Package\",\n\x0fPackageInfoResp\x12\x19\n\x03pkg\x18\x01 \x01(\x0b\x32\x0c.api.Package\"(\n\nPackageAdd\x12\x1a\n\x04pkgs\x18\x01 \x03(\x0b\x32\x0c.api.Package\"+\n\rPackageRemove\x12\x1a\n\x04pkgs\x18\x01 \x03(\x0b\x32\x0c.api.Package\"%\n\x0ePackageInstall\x12\x13\n\x0b\x66romHosting\x18\x01 \x01(\x08\"\x15\n\x13PackageListSpecfile\"5\n\x17PackageListSpecfileResp\x12\x1a\n\x04pkgs\x18\x01 \x03(\x0b\x32\x0c.api.Package\"\x12\n\x10PackageCacheSave\"6\n\x0e\x43hatScrollback\x12$\n\nscrollback\x18\x01 \x03(\x0b\x32\x10.api.ChatMessage\"+\n\x07Metrics\x12 \n\x18prometheusMetricFamilies\x18\x01 \x03(\x0c\"\xed\x02\n\x0cPprofRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12=\n\x16pprofCpuProfileRequest\x18\x02 \x01(\x0b\x32\x1b.api.PprofCpuProfileRequestH\x00\x12?\n\x17pprofHeapProfileRequest\x18\x03 \x01(\x0b\x32\x1c.api.PprofHeapProfileRequestH\x00\x12\x43\n\x19pprofAllocsProfileRequest\x18\x04 \x01(\x0b\x32\x1e.api.PprofAllocsProfileRequestH\x00\x12\x41\n\x18pprofBlockProfileRequest\x18\x05 \x01(\x0b\x32\x1d.api.PprofBlockProfileRequestH\x00\x12\x41\n\x18pprofMutexProfileRequest\x18\x06 \x01(\x0b\x32\x1d.api.PprofMutexProfileRequestH\x00\x42\x06\n\x04\x62ody\"*\n\x19PprofAllocsProfileRequest\x12\r\n\x05\x64\x65\x62ug\x18\x01 \x01(\x08\")\n\x18PprofBlockProfileRequest\x12\r\n\x05\x64\x65\x62ug\x18\x01 \x01(\x08\")\n\x16PprofCpuProfileRequest\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\"4\n\x17PprofHeapProfileRequest\x12\n\n\x02gc\x18\x01 \x01(\x08\x12\r\n\x05\x64\x65\x62ug\x18\x02 \x01(\x08\")\n\x18PprofMutexProfileRequest\x12\r\n\x05\x64\x65\x62ug\x18\x01 \x01(\x08\",\n\rPprofResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07profile\x18\x02 \x01(\x0c\"\x1d\n\tPTYConfig\x12\x10\n\x08pipeMode\x18\x01 \x01(\x08\"T\n\tDebugMain\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x10\n\x08readOnly\x18\x02 \x01(\x08\x12\x10\n\x08\x66ilePath\x18\x03 \x01(\t\x12\x12\n\ndebuggerId\x18\x04 \x01(\t\"e\n\x0e\x44\x65\x62ugMainReply\x12\x0e\n\x06joined\x18\x01 \x01(\x08\x12.\n\x08protocol\x18\x02 \x01(\x0e\x32\x1c.api.DebugMainReply.Protocol\"\x13\n\x08Protocol\x12\x07\n\x03\x44\x41P\x10\x00\"8\n\nDebugState\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x19\n\x05state\x18\x02 \x01(\x0e\x32\n.api.State\"P\n\nDebugInput\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x0f\n\x05input\x18\x02 \x01(\tH\x00\x12\x16\n\x0c\x61\x64\x61pterInput\x18\x03 \x01(\tH\x00\x42\x08\n\x06stream\"S\n\x0b\x44\x65\x62ugOutput\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x10\n\x06output\x18\x02 \x01(\tH\x00\x12\x17\n\radapterOutput\x18\x03 \x01(\tH\x00\x42\x08\n\x06stream\"\x1c\n\tDebugStop\x12\x0f\n\x07session\x18\x01 \x01(\t\"\x1d\n\nDebugLeave\x12\x0f\n\x07session\x18\x01 \x01(\t\"\x80\x01\n\rDebugSessions\x12\x32\n\x08sessions\x18\x01 \x03(\x0b\x32 .api.DebugSessions.SessionsEntry\x1a;\n\rSessionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x19\n\x05value\x18\x02 \x01(\x0e\x32\n.api.State:\x02\x38\x01\"\x15\n\x13\x44otReplitGetRequest\"9\n\x14\x44otReplitGetResponse\x12!\n\tdotReplit\x18\x01 \x01(\x0b\x32\x0e.api.DotReplit\"\x15\n\x13RunConfigGetRequest\"\xb1\x01\n\x14RunConfigGetResponse\x12&\n\x06interp\x18\x01 \x01(\x0b\x32\x14.api.DotReplitInterpH\x00\x12,\n\x03run\x18\x02 \x01(\x0b\x32\x1d.api.RunConfigGetResponse.RunH\x00\x1a\x39\n\x03Run\x12\x1a\n\x07\x63ompile\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x16\n\x03run\x18\x02 \x01(\x0b\x32\t.api.ExecB\x08\n\x06\x63onfig\"<\n\x11\x44otReplitUpdateOp\x12\n\n\x02op\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"=\n\x16\x44otReplitUpdateRequest\x12#\n\x03ops\x18\x01 \x03(\x0b\x32\x16.api.DotReplitUpdateOp\"\x19\n\x17\x44otReplitUpdateResponse\"\x85\x01\n\x19\x44\x65\x62ugAddBreakpointRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\totVersion\x18\x02 \x01(\r\x12\x0f\n\x07otIndex\x18\x03 \x01(\r\x12\x14\n\x0csessionLocal\x18\x06 \x01(\x08\x12\x0c\n\x04line\x18\x04 \x01(\x05\x12\x12\n\nlogMessage\x18\x05 \x01(\t\"H\n\x1c\x44\x65\x62ugUpdateBreakpointRequest\x12\x14\n\x0c\x62reakpointId\x18\x01 \x01(\t\x12\x12\n\nlogMessage\x18\x02 \x01(\t\"4\n\x1c\x44\x65\x62ugRemoveBreakpointRequest\x12\x14\n\x0c\x62reakpointId\x18\x02 \x01(\t\"e\n\x14\x44\x65\x62ugBreakpointEvent\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x62solutePath\x18\x03 \x01(\t\x12)\n\x0b\x62reakpoints\x18\x02 \x03(\x0b\x32\x14.api.DebugBreakpoint\"\x83\x01\n\x0f\x44\x65\x62ugBreakpoint\x12\x14\n\x0c\x62reakpointId\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\x05\x12\x11\n\totVersion\x18\x03 \x01(\r\x12\x0f\n\x07otIndex\x18\x04 \x01(\r\x12\x14\n\x0csessionLocal\x18\x06 \x01(\x08\x12\x12\n\nlogMessage\x18\x05 \x01(\t\"\xa0\x07\n\tDotReplit\x12\x16\n\x03run\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x1a\n\x07\x63ompile\x18\x02 \x01(\x0b\x32\t.api.Exec\x12%\n\x08\x64\x65\x62ugger\x18\x03 \x01(\x0b\x32\x13.api.DebuggerConfig\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x19\n\x06onBoot\x18\x05 \x01(\x0b\x32\t.api.Exec\x12(\n\x08packager\x18\x06 \x01(\x0b\x32\x16.api.DotReplitPackager\x12)\n\x0binterpreter\x18\x07 \x01(\x0b\x32\x14.api.DotReplitInterp\x12\x12\n\nentrypoint\x18\x08 \x01(\t\x12\x30\n\tlanguages\x18\t \x03(\x0b\x32\x1d.api.DotReplit.LanguagesEntry\x12(\n\x08unitTest\x18\n \x01(\x0b\x32\x16.api.DotReplitUnitTest\x12\x0e\n\x06hidden\x18\x0b \x03(\t\x12\x1b\n\x03nix\x18\x0c \x01(\x0b\x32\x0e.api.NixConfig\x12\r\n\x05\x61udio\x18\r \x01(\x08\x12#\n\x07hosting\x18\x0e \x01(\x0b\x32\x12.api.HostingConfig\x12$\n\x03\x65nv\x18\x0f \x03(\x0b\x32\x17.api.DotReplit.EnvEntry\x12-\n\x0cgitHubImport\x18\x10 \x01(\x0b\x32\x17.api.GitHubImportConfig\x12\x1d\n\x04\x61uth\x18\x11 \x01(\x0b\x32\x0f.api.AuthConfig\x12%\n\thintsList\x18\x12 \x03(\x0b\x32\x12.api.DotReplitHint\x12!\n\x05ports\x18\x13 \x03(\x0b\x32\x12.api.DotReplitPort\x12(\n\norderedEnv\x18\x14 \x03(\x0b\x32\x14.api.DotReplitEnvVar\x12\"\n\x1arefreshWebViewOnFileChange\x18\x15 \x03(\t\x12)\n\ndeployment\x18\x16 \x01(\x0b\x32\x15.api.DeploymentConfig\x12\x0f\n\x07modules\x18\x17 \x03(\t\x12\'\n\textension\x18\x18 \x01(\x0b\x32\x14.api.ExtensionConfig\x1aH\n\x0eLanguagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.api.DotReplitLanguage:\x02\x38\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x0f\x44otReplitEnvVar\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"8\n\rDotReplitPort\x12\x11\n\tlocalPort\x18\x01 \x01(\r\x12\x14\n\x0c\x65xternalPort\x18\x02 \x01(\r\"/\n\rDotReplitHint\x12\r\n\x05regex\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"+\n\x12GitHubImportConfig\x12\x15\n\rrequiredFiles\x18\x01 \x03(\t\"\xc7\x01\n\x10\x44\x65ploymentConfig\x12\x16\n\x03run\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x18\n\x05\x62uild\x18\x02 \x01(\x0b\x32\t.api.Exec\x12\x13\n\x0bignorePorts\x18\x03 \x01(\x08\x12,\n\x06target\x18\x04 \x01(\x0e\x32\x1c.api.DeploymentConfig.Target\x12\x11\n\tpublicDir\x18\x05 \x01(\t\"+\n\x06Target\x12\x07\n\x03GCE\x10\x00\x12\x0c\n\x08\x43LOUDRUN\x10\x01\x12\n\n\x06STATIC\x10\x02\"j\n\x0f\x45xtensionConfig\x12\x13\n\x0bisExtension\x18\x01 \x01(\x08\x12\x13\n\x0b\x65xtensionID\x18\x02 \x01(\t\x12\x14\n\x0c\x62uildCommand\x18\x03 \x01(\t\x12\x17\n\x0foutputDirectory\x18\x04 \x01(\t\"\x1c\n\tNixConfig\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\"1\n\rHostingConfig\x12\r\n\x05route\x18\x01 \x01(\t\x12\x11\n\tdirectory\x18\x02 \x01(\t\"\x8a\x01\n\nAuthConfig\x12\x13\n\x0bpageEnabled\x18\x01 \x01(\x08\x12\x11\n\tpageTitle\x18\x02 \x01(\t\x12\x17\n\x0fpageDescription\x18\x03 \x01(\t\x12\x11\n\tpageColor\x18\x04 \x01(\t\x12\x11\n\tpageImage\x18\x05 \x01(\t\x12\x15\n\rbuttonEnabled\x18\x06 \x01(\x08\"=\n\x0f\x44otReplitInterp\x12\x1a\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x0e\n\x06prompt\x18\x02 \x01(\x0c\"g\n\x11\x44otReplitLanguage\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12\x0e\n\x06syntax\x18\x02 \x01(\t\x12\x31\n\x0elanguageServer\x18\x03 \x01(\x0b\x32\x19.api.LanguageServerConfig\"u\n\x14LanguageServerConfig\x12\x1f\n\x0cstartCommand\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x19\n\x11\x63onfigurationJson\x18\x02 \x01(\t\x12!\n\x19initializationOptionsJson\x18\x03 \x01(\t\"\x81\x02\n\x11\x44otReplitPackager\x12\x1f\n\x0c\x61\x66terInstall\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x30\n\x08\x66\x65\x61tures\x18\x05 \x01(\x0b\x32\x1e.api.DotReplitPackagerFeatures\x12,\n\x03\x65nv\x18\x06 \x03(\x0b\x32\x1f.api.DotReplitPackager.EnvEntry\x12\x14\n\x0cignoredPaths\x18\x02 \x03(\t\x12\x17\n\x0fignoredPackages\x18\x03 \x03(\t\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x19\x44otReplitPackagerFeatures\x12\x15\n\rpackageSearch\x18\x01 \x01(\x08\x12\x14\n\x0cguessImports\x18\x02 \x01(\x08\x12\x19\n\x11\x65nabledForHosting\x18\x03 \x01(\x08\"%\n\x11\x44otReplitUnitTest\x12\x10\n\x08language\x18\x01 \x01(\t\"\x94\x03\n\x0e\x44\x65\x62uggerConfig\x12\x0f\n\x07support\x18\x01 \x01(\x08\x12#\n\x07\x63ompile\x18\x02 \x01(\x0b\x32\x12.api.CompileConfig\x12#\n\x0binteractive\x18\x03 \x01(\x0b\x32\x0e.api.DapConfig\x12)\n\ntimeTravel\x18\x04 \x01(\x0b\x32\x15.api.TimeTravelConfig\x12\x14\n\x0c\x64\x61pTransport\x18\x05 \x01(\t\x12\x19\n\x11\x64\x61pConnectTimeout\x18\x06 \x01(\x03\x12=\n\x14\x64\x61pIntegratedAdapter\x18\x07 \x01(\x0b\x32\x1f.api.DapIntegratedAdapterConfig\x12\"\n\x0f\x64\x61pStartCommand\x18\x08 \x01(\x0b\x32\t.api.Exec\x12\x35\n\x14\x64\x61pInitializeMessage\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10\x64\x61pLaunchMessage\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\"Q\n\rCompileConfig\x12\x1a\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x10\n\x08onlyMain\x18\x02 \x01(\x08\x12\x12\n\nnoFileArgs\x18\x03 \x01(\x08\"\xf7\x01\n\tDapConfig\x12\x11\n\ttransport\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectTimeout\x18\x02 \x01(\x03\x12:\n\x11integratedAdapter\x18\x03 \x01(\x0b\x32\x1f.api.DapIntegratedAdapterConfig\x12\x1f\n\x0cstartCommand\x18\x04 \x01(\x0b\x32\t.api.Exec\x12\x32\n\x11initializeMessage\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\rlaunchMessage\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"L\n\x10TimeTravelConfig\x12\x19\n\x06record\x18\x01 \x01(\x0b\x32\t.api.Exec\x12\x1d\n\x05\x64\x65\x62ug\x18\x02 \x01(\x0b\x32\x0e.api.DapConfig\"3\n\x1a\x44\x61pIntegratedAdapterConfig\x12\x15\n\rdapTcpAddress\x18\x01 \x01(\t\"\x10\n\x0eProxyGoingAway\"\x10\n\x0e\x46irewallDenied\"r\n\x0eReplLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06replId\x18\x02 \x01(\t\x12\x0f\n\x07logLine\x18\x03 \x01(\t\x12\x10\n\x08userName\x18\x04 \x01(\t\"[\n\tUserEvent\x12\x11\n\teventName\x18\x01 \x01(\t\x12*\n\teventData\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07version\x18\x03 \x01(\x05\"\x16\n\x14NixModulesGetRequest\"8\n\x15NixModulesGetResponse\x12\x1f\n\x07modules\x18\x01 \x03(\x0b\x32\x0e.api.NixModule\"\xf0\x01\n\tNixModule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1f\n\x07runners\x18\x05 \x03(\x0b\x32\x0e.api.RunOption\x12&\n\tdebuggers\x18\x06 \x03(\x0b\x32\x13.api.DebuggerOption\x12&\n\tpackagers\x18\x07 \x03(\x0b\x32\x13.api.PackagerOption\x12\x32\n\x0flanguageServers\x18\x08 \x03(\x0b\x32\x19.api.LanguageServerOption\"4\n\x11NixModulesChanged\x12\x1f\n\x07modules\x18\x01 \x03(\x0b\x32\x0e.api.NixModule\"\x18\n\x16NixModulesBuildRequest\"\x15\n\x13ToolchainGetRequest\"\xc8\x01\n\x10ToolchainConfigs\x12\x12\n\nentrypoint\x18\x01 \x01(\t\x12\x1c\n\x04runs\x18\x02 \x03(\x0b\x32\x0e.api.RunOption\x12&\n\tdebuggers\x18\x03 \x03(\x0b\x32\x13.api.DebuggerOption\x12\x32\n\x0flanguageServers\x18\x04 \x03(\x0b\x32\x19.api.LanguageServerOption\x12&\n\tpackagers\x18\x05 \x03(\x0b\x32\x13.api.PackagerOption\">\n\x14ToolchainGetResponse\x12&\n\x07\x63onfigs\x18\x01 \x01(\x0b\x32\x15.api.ToolchainConfigs\":\n\x10ToolchainChanged\x12&\n\x07\x63onfigs\x18\x01 \x01(\x0b\x32\x15.api.ToolchainConfigs\"u\n\tRunOption\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfileParam\x18\x03 \x01(\x08\x12\x10\n\x08language\x18\x04 \x01(\t\x12)\n\rfileTypeAttrs\x18\x05 \x01(\x0b\x32\x12.api.FileTypeAttrs\"z\n\x0e\x44\x65\x62uggerOption\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfileParam\x18\x03 \x01(\x08\x12\x10\n\x08language\x18\x04 \x01(\t\x12)\n\rfileTypeAttrs\x18\x05 \x01(\x0b\x32\x12.api.FileTypeAttrs\"\x98\x01\n\x14LanguageServerOption\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\x12)\n\rfileTypeAttrs\x18\x04 \x01(\x0b\x32\x12.api.FileTypeAttrs\x12)\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x19.api.LanguageServerConfig\"G\n\rFileTypeAttrs\x12\x12\n\nextensions\x18\x01 \x03(\t\x12\r\n\x05\x66iles\x18\x02 \x03(\t\x12\x13\n\x0b\x66ilePattern\x18\x03 \x01(\t\"\x9b\x01\n\x0ePackagerOption\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\x12\x15\n\rpackagerFiles\x18\x04 \x03(\t\x12\x19\n\x11\x65nabledForHosting\x18\x05 \x01(\x08\x12\x15\n\rpackageSearch\x18\x06 \x01(\x08\x12\x14\n\x0cguessImports\x18\x07 \x01(\x08\"B\n\x14ReplDomainDoubleDash\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x0e\n\x06suffix\x18\x03 \x01(\t\"<\n\x0eReplDomainDots\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x0e\n\x06suffix\x18\x03 \x01(\t\"6\n\x16ReplDomainSingleDomain\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06suffix\x18\x02 \x01(\t\"*\n\x0cReplDomainId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06suffix\x18\x02 \x01(\t\"\xd2\x01\n\nReplDomain\x12\x10\n\x06\x63ustom\x18\x01 \x01(\tH\x00\x12\x1f\n\x02id\x18\x02 \x01(\x0b\x32\x11.api.ReplDomainIdH\x00\x12/\n\ndoubleDash\x18\x03 \x01(\x0b\x32\x19.api.ReplDomainDoubleDashH\x00\x12#\n\x04\x64ots\x18\x04 \x01(\x0b\x32\x13.api.ReplDomainDotsH\x00\x12\x33\n\x0csingleDomain\x18\x05 \x01(\x0b\x32\x1b.api.ReplDomainSingleDomainH\x00\x42\x06\n\x04kind\"\xb9\x06\n\tReplToken\x12\'\n\x03iat\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65xp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04salt\x18\x03 \x01(\t\x12\x0f\n\x07\x63luster\x18\x04 \x01(\t\x12*\n\x0bpersistence\x18\x06 \x01(\x0e\x32\x15.api.repl.Persistence\x12\x30\n\x0eresourceLimits\x18\n \x01(\x0b\x32\x18.api.repl.ResourceLimits\x12;\n\x19interactiveResourceLimits\x18\x11 \x01(\x0b\x32\x18.api.repl.ResourceLimits\x12)\n\x06\x66ormat\x18\x0c \x01(\x0e\x32\x19.api.ReplToken.WireFormat\x12+\n\tpresenced\x18\r \x01(\x0b\x32\x18.api.ReplToken.Presenced\x12\r\n\x05\x66lags\x18\x0e \x03(\t\x12*\n\x0bpermissions\x18\x0f \x01(\x0b\x32\x15.api.repl.Permissions\x12\'\n\x08\x66\x65\x61tures\x18\x10 \x03(\x0b\x32\x15.api.features.Feature\x12&\n\tbuildInfo\x18\x12 \x01(\x0b\x32\x13.api.repl.BuildInfo\x12\x1e\n\x04repl\x18\x07 \x01(\x0b\x32\x0e.api.repl.ReplH\x00\x12#\n\x02id\x18\x08 \x01(\x0b\x32\x15.api.ReplToken.ReplIDH\x00\x12\x35\n\tclassroom\x18\t \x01(\x0b\x32 .api.ReplToken.ClassroomMetadataH\x00\x1a\x31\n\x11\x43lassroomMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x1a(\n\x06ReplID\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsourceRepl\x18\x02 \x01(\t\x1a\x31\n\tPresenced\x12\x10\n\x08\x62\x65\x61rerID\x18\x01 \x01(\r\x12\x12\n\nbearerName\x18\x02 \x01(\t\"$\n\nWireFormat\x12\x0c\n\x08PROTOBUF\x10\x00\x12\x08\n\x04JSON\x10\x01\x42\n\n\x08metadata\".\n\x0eTLSCertificate\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0c\n\x04\x63\x65rt\x18\x02 \x01(\x0c\"\xd9\x01\n\x0cReplTransfer\x12\x1c\n\x04repl\x18\x01 \x01(\x0b\x32\x0e.api.repl.Repl\x12,\n\nreplLimits\x18\x02 \x01(\x0b\x32\x18.api.repl.ResourceLimits\x12,\n\nuserLimits\x18\x03 \x01(\x0b\x32\x18.api.repl.ResourceLimits\x12\x15\n\rcustomDomains\x18\x04 \x03(\t\x12)\n\x0c\x63\x65rtificates\x18\x05 \x03(\x0b\x32\x13.api.TLSCertificate\x12\r\n\x05\x66lags\x18\x06 \x03(\t\";\n\x10\x41llowReplRequest\x12\'\n\x0creplTransfer\x18\x01 \x01(\x0b\x32\x11.api.ReplTransfer\"`\n\x0f\x43lusterMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tconmanURL\x18\x02 \x01(\t\x12\x0c\n\x04gurl\x18\x03 \x01(\t\x12\r\n\x05proxy\x18\x05 \x01(\t\x12\x11\n\tcontinent\x18\x07 \x01(\t\"l\n\x10\x45victReplRequest\x12-\n\x0f\x63lusterMetadata\x18\x01 \x01(\x0b\x32\x14.api.ClusterMetadata\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t\"<\n\x11\x45victReplResponse\x12\'\n\x0creplTransfer\x18\x01 \x01(\x0b\x32\x11.api.ReplTransfer\"z\n\x15GovalSigningAuthority\x12\"\n\x07version\x18\x03 \x01(\x0e\x32\x11.api.TokenVersion\x12\x0e\n\x06issuer\x18\x04 \x01(\t\x12\x0f\n\x05keyId\x18\x01 \x01(\tH\x00\x12\x14\n\nsignedCert\x18\x02 \x01(\tH\x00\x42\x06\n\x04\x63\x65rt\"p\n\x10\x43\x65rtificateClaim\x12\x10\n\x06replid\x18\x01 \x01(\tH\x00\x12\x0e\n\x04user\x18\x02 \x01(\tH\x00\x12\x11\n\x07\x63luster\x18\x04 \x01(\tH\x00\x12\x1e\n\x04\x66lag\x18\x03 \x01(\x0e\x32\x0e.api.FlagClaimH\x00\x42\x07\n\x05\x63laim\"\x97\x01\n\tGovalCert\x12\'\n\x03iat\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65xp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\x06\x63laims\x18\x03 \x03(\x0b\x32\x15.api.CertificateClaim\x12\x11\n\tpublicKey\x18\x04 \x01(\t\"\xcc\x01\n\nGovalToken\x12\'\n\x03iat\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65xp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06replid\x18\x03 \x01(\t\x12#\n\treplToken\x18\x04 \x01(\x0b\x32\x0e.api.ReplTokenH\x00\x12.\n\x0creplIdentity\x18\x05 \x01(\x0b\x32\x16.api.GovalReplIdentityH\x00\x42\x07\n\x05Token\"\xad\x01\n\x11GovalReplIdentity\x12\x0e\n\x06replid\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x0b\n\x03\x61ud\x18\x04 \x01(\t\x12\x11\n\tephemeral\x18\x05 \x01(\x08\x12\x14\n\x0coriginReplid\x18\x06 \x01(\t\x12\x0e\n\x06userId\x18\x07 \x01(\x03\x12&\n\tbuildInfo\x18\x08 \x01(\x0b\x32\x13.api.repl.BuildInfo\"\x93\n\n\x04lore\x1a\xb6\x02\n\x0bLoreCommand\x12\x34\n\x0f\x63lusterTransfer\x18\x01 \x01(\x0b\x32\x19.api.lore.ClusterTransferH\x00\x12.\n\x0csoftTakedown\x18\x02 \x01(\x0b\x32\x16.api.lore.SoftTakedownH\x00\x12&\n\x08takedown\x18\x06 \x01(\x0b\x32\x12.api.lore.TakedownH\x00\x12.\n\x0cgovalCommand\x18\x03 \x01(\x0b\x32\x16.api.lore.GovalCommandH\x00\x12\x38\n\x11multiGovalCommand\x18\x05 \x01(\x0b\x32\x1b.api.lore.MultiGovalCommandH\x00\x12$\n\x07restore\x18\x04 \x01(\x0b\x32\x11.api.lore.RestoreH\x00\x42\t\n\x07\x63ommand\x1a\x81\x01\n\x0f\x43lusterTransfer\x12\x0e\n\x06replId\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x12\n\ntransferId\x18\x04 \x01(\t\x12\x16\n\x0cnewClusterId\x18\x03 \x01(\tH\x00\x12\x18\n\x0enewContinentId\x18\x05 \x01(\tH\x00\x42\n\n\x08location\x1a\x36\n\x0cSoftTakedown\x12\x0e\n\x06replId\x18\x01 \x01(\t\x12\x16\n\x0esoftTakedownId\x18\x02 \x01(\t\x1a\x1a\n\x08Takedown\x12\x0e\n\x06replId\x18\x01 \x01(\t\x1a\xf7\x02\n\x0cGovalCommand\x12,\n\x0eupdateMetadata\x18\x01 \x01(\x0b\x32\x12.api.repl.MetadataH\x00\x12@\n\x15partialUpdateMetadata\x18\x02 \x01(\x0b\x32\x1f.api.lore.PartialUpdateMetadataH\x00\x12&\n\x08killRepl\x18\x03 \x01(\x0b\x32\x12.api.lore.KillReplH\x00\x12\x36\n\x10updateSourceRepl\x18\x04 \x01(\x0b\x32\x1a.api.lore.UpdateSourceReplH\x00\x12\x34\n\x0fupdateReplFlags\x18\x05 \x01(\x0b\x32\x19.api.lore.UpdateReplFlagsH\x00\x12.\n\x0csoftTakedown\x18\x06 \x01(\x0b\x32\x16.api.lore.SoftTakedownH\x00\x12&\n\x08takedown\x18\x07 \x01(\x0b\x32\x12.api.lore.TakedownH\x00\x42\t\n\x07\x63ommand\x1ar\n\x15PartialUpdateMetadata\x12-\n\tfieldMask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12*\n\x0eupdateMetadata\x18\x02 \x01(\x0b\x32\x12.api.repl.Metadata\x1aR\n\x11MultiGovalCommand\x12\x0e\n\x06replId\x18\x01 \x01(\t\x12-\n\rgovalCommands\x18\x02 \x03(\x0b\x32\x16.api.lore.GovalCommand\x1a\x1a\n\x08KillRepl\x12\x0e\n\x06replId\x18\x01 \x01(\t\x1a\x30\n\x07Restore\x12\x0e\n\x06replId\x18\x01 \x01(\t\x12\x15\n\rrestoreReplId\x18\x02 \x01(\t\x1a\x38\n\x10UpdateSourceRepl\x12\x0e\n\x06replId\x18\x01 \x01(\t\x12\x14\n\x0csourceReplId\x18\x02 \x01(\t\x1a\x30\n\x0fUpdateReplFlags\x12\x0e\n\x06replId\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x03(\t\"\x90\x01\n\x08\x66\x65\x61tures\x1a\x05\n\x03Gpu\x1a\t\n\x07\x42oosted\x1ar\n\x07\x46\x65\x61ture\x12\x10\n\x08required\x18\x03 \x01(\x08\x12 \n\x03gpu\x18\x01 \x01(\x0b\x32\x11.api.features.GpuH\x00\x12(\n\x07\x62oosted\x18\x02 \x01(\x0b\x32\x15.api.features.BoostedH\x00\x42\t\n\x07\x66\x65\x61ture\"\xee\x08\n\x04repl\x1a.\n\x07\x42uckets\x12\x11\n\tsnapshots\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x1a\xbc\x01\n\x04Repl\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x05 \x01(\t\x12\x12\n\nsourceRepl\x18\x06 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x07 \x01(\t\x12\"\n\x07\x62uckets\x18\x08 \x01(\x0b\x32\x11.api.repl.Buckets\x12 \n\x06userId\x18\t \x01(\x0b\x32\x10.api.repl.UserId\x1a@\n\x06UserId\x12\n\n\x02id\x18\x01 \x01(\x03\x12*\n\x0b\x65nvironment\x18\x02 \x01(\x0e\x32\x15.api.repl.Environment\x1a\xee\x01\n\x0eResourceLimits\x12\x0b\n\x03net\x18\x01 \x01(\x08\x12\x0e\n\x06memory\x18\x02 \x01(\x03\x12\x0f\n\x07threads\x18\x03 \x01(\x01\x12\x0e\n\x06shares\x18\x04 \x01(\x01\x12\x0c\n\x04\x64isk\x18\x05 \x01(\x03\x12\x33\n\x05\x63\x61\x63he\x18\x06 \x01(\x0e\x32$.api.repl.ResourceLimits.Cachability\x12\x17\n\x0frestrictNetwork\x18\x07 \x01(\x08\x12\x15\n\rpreventWakeup\x18\x08 \x01(\x08\"+\n\x0b\x43\x61\x63hability\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04USER\x10\x01\x12\x08\n\x04REPL\x10\x02\x1a%\n\x0bPermissions\x12\x16\n\x0etoggleAlwaysOn\x18\x01 \x01(\x08\x1a\xcf\x02\n\x08Metadata\x12\x1c\n\x04repl\x18\x07 \x01(\x0b\x32\x0e.api.repl.Repl\x12\x30\n\x0eresourceLimits\x18\n \x01(\x0b\x32\x18.api.repl.ResourceLimits\x12;\n\x19interactiveResourceLimits\x18\x11 \x01(\x0b\x32\x18.api.repl.ResourceLimits\x12*\n\x0bpersistence\x18\x06 \x01(\x0e\x32\x15.api.repl.Persistence\x12\r\n\x05\x66lags\x18\x0e \x03(\t\x12*\n\x0bpermissions\x18\x0f \x01(\x0b\x32\x15.api.repl.Permissions\x12\'\n\x08\x66\x65\x61tures\x18\x10 \x03(\x0b\x32\x15.api.features.Feature\x12&\n\tbuildInfo\x18\x12 \x01(\x0b\x32\x13.api.repl.BuildInfo\x1aT\n\tBuildInfo\x12\x14\n\x0c\x64\x65ploymentId\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0f\n\x07\x62uildId\x18\x03 \x01(\t\x12\x13\n\x0bmachineTier\x18\x04 \x01(\t\".\n\x0b\x45nvironment\x12\x0f\n\x0b\x44\x45VELOPMENT\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\"E\n\x0bPersistence\x12\x0e\n\nPERSISTENT\x10\x00\x12\r\n\tEPHEMERAL\x10\x01\x12\x08\n\x04NONE\x10\x02\x12\r\n\tREAD_ONLY\x10\x03\"&\n\x13PrivateReplsPowerup\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"%\n\x12GhostwriterPowerup\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"&\n\x13\x43onnectivityPowerup\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xd2\x01\n\x07PowerUp\x12-\n\texpiresAt\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07private\x18\n \x01(\x0b\x32\x18.api.PrivateReplsPowerupH\x00\x12.\n\x0bghostwriter\x18\x0b \x01(\x0b\x32\x17.api.GhostwriterPowerupH\x00\x12\x30\n\x0c\x63onnectivity\x18\x0c \x01(\x0b\x32\x18.api.ConnectivityPowerupH\x00\x42\t\n\x07powerup\"P\n\x0cUserPowerUps\x12\x0e\n\x06userId\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x1e\n\x08powerups\x18\x03 \x03(\x0b\x32\x0c.api.PowerUp*8\n\x0e\x46ileAuthMethod\x12\x07\n\x03GET\x10\x00\x12\x08\n\x04HEAD\x10\x01\x12\x07\n\x03PUT\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03*!\n\x05State\x12\x0b\n\x07Stopped\x10\x00\x12\x0b\n\x07Running\x10\x01*9\n\x0cTokenVersion\x12\x13\n\x0f\x42\x41RE_REPL_TOKEN\x10\x00\x12\x14\n\x10TYPE_AWARE_TOKEN\x10\x01*\xad\x01\n\tFlagClaim\x12\x14\n\x10MINT_GOVAL_TOKEN\x10\x00\x12\x1a\n\x16SIGN_INTERMEDIATE_CERT\x10\x01\x12\x0c\n\x08IDENTITY\x10\x05\x12\x0f\n\x0bGHOSTWRITER\x10\x06\x12\x12\n\x0eRENEW_IDENTITY\x10\x07\x12\x0c\n\x08RENEW_KV\x10\x08\x12\x0e\n\nANY_REPLID\x10\x02\x12\x0c\n\x08\x41NY_USER\x10\x03\x12\x0f\n\x0b\x41NY_CLUSTER\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMAND_TRACEINFOENTRY._options = None
  _COMMAND_TRACEINFOENTRY._serialized_options = b'8\001'
  _PID1CONFIG_ENVENTRY._options = None
  _PID1CONFIG_ENVENTRY._serialized_options = b'8\001'
  _EXEC_ENVENTRY._options = None
  _EXEC_ENVENTRY._serialized_options = b'8\001'
  _DEBUGSESSIONS_SESSIONSENTRY._options = None
  _DEBUGSESSIONS_SESSIONSENTRY._serialized_options = b'8\001'
  _DOTREPLIT_LANGUAGESENTRY._options = None
  _DOTREPLIT_LANGUAGESENTRY._serialized_options = b'8\001'
  _DOTREPLIT_ENVENTRY._options = None
  _DOTREPLIT_ENVENTRY._serialized_options = b'8\001'
  _DOTREPLITPACKAGER_ENVENTRY._options = None
  _DOTREPLITPACKAGER_ENVENTRY._serialized_options = b'8\001'
  _FILEAUTHMETHOD._serialized_start=28815
  _FILEAUTHMETHOD._serialized_end=28871
  _STATE._serialized_start=28873
  _STATE._serialized_end=28906
  _TOKENVERSION._serialized_start=28908
  _TOKENVERSION._serialized_end=28965
  _FLAGCLAIM._serialized_start=28968
  _FLAGCLAIM._serialized_end=29141
  _COMMAND._serialized_start=116
  _COMMAND._serialized_end=8020
  _COMMAND_TRACEINFOENTRY._serialized_start=7964
  _COMMAND_TRACEINFOENTRY._serialized_end=8012
  _NIXPACKAGEADDREQUEST._serialized_start=8022
  _NIXPACKAGEADDREQUEST._serialized_end=8062
  _NIXPACKAGEADDRESPONSE._serialized_start=8064
  _NIXPACKAGEADDRESPONSE._serialized_end=8087
  _NIXPACKAGEREMOVEREQUEST._serialized_start=8089
  _NIXPACKAGEREMOVEREQUEST._serialized_end=8132
  _NIXPACKAGEREMOVERESPONSE._serialized_start=8134
  _NIXPACKAGEREMOVERESPONSE._serialized_end=8160
  _NIXPACKAGELISTREQUEST._serialized_start=8162
  _NIXPACKAGELISTREQUEST._serialized_end=8185
  _NIXPACKAGELISTRESPONSE._serialized_start=8187
  _NIXPACKAGELISTRESPONSE._serialized_end=8246
  _NIXPACKAGE._serialized_start=8248
  _NIXPACKAGE._serialized_end=8372
  _NIXCHANNELSREQUEST._serialized_start=8374
  _NIXCHANNELSREQUEST._serialized_end=8394
  _NIXCHANNELSRESPONSE._serialized_start=8396
  _NIXCHANNELSRESPONSE._serialized_end=8435
  _NIXCHANNELLATESTSTABLEREQUEST._serialized_start=8437
  _NIXCHANNELLATESTSTABLEREQUEST._serialized_end=8468
  _NIXCHANNELLATESTSTABLERESPONSE._serialized_start=8470
  _NIXCHANNELLATESTSTABLERESPONSE._serialized_end=8519
  _NIXPACKAGESEARCHREQUEST._serialized_start=8521
  _NIXPACKAGESEARCHREQUEST._serialized_end=8561
  _NIXPACKAGESEARCHRESPONSE._serialized_start=8563
  _NIXPACKAGESEARCHRESPONSE._serialized_end=8624
  _STARTLSP._serialized_start=8626
  _STARTLSP._serialized_end=8680
  _AUDIO._serialized_start=8682
  _AUDIO._serialized_end=8703
  _AUDIO2._serialized_start=8705
  _AUDIO2._serialized_end=8744
  _PRECONDITIONS._serialized_start=8746
  _PRECONDITIONS._serialized_end=8827
  _READMETAREQUEST._serialized_start=8829
  _READMETAREQUEST._serialized_end=8889
  _READMETARESPONSE._serialized_start=8891
  _READMETARESPONSE._serialized_end=8996
  _WRITEMETAREQUEST._serialized_start=8998
  _WRITEMETAREQUEST._serialized_end=9086
  _WRITEMETARESPONSE._serialized_start=9088
  _WRITEMETARESPONSE._serialized_end=9151
  _APPENDMETAREQUEST._serialized_start=9153
  _APPENDMETAREQUEST._serialized_end=9242
  _APPENDMETARESPONSE._serialized_start=9244
  _APPENDMETARESPONSE._serialized_end=9308
  _BOOTSTATUS._serialized_start=9311
  _BOOTSTATUS._serialized_end=9522
  _BOOTSTATUS_STAGE._serialized_start=9396
  _BOOTSTATUS_STAGE._serialized_end=9522
  _PID1CONFIG._serialized_start=9525
  _PID1CONFIG._serialized_end=9700
  _PID1CONFIG_ENVENTRY._serialized_start=9658
  _PID1CONFIG_ENVENTRY._serialized_end=9700
  _FSLOCK._serialized_start=9702
  _FSLOCK._serialized_end=9724
  _FSSNAPSHOT._serialized_start=9726
  _FSSNAPSHOT._serialized_end=9738
  _FSSNAPSHOTEVENT._serialized_start=9740
  _FSSNAPSHOTEVENT._serialized_end=9774
  _SNAPSHOTEVENT._serialized_start=9776
  _SNAPSHOTEVENT._serialized_end=9808
  _SUBSCRIBEFILE._serialized_start=9810
  _SUBSCRIBEFILE._serialized_end=9851
  _FILEEVENT._serialized_start=9854
  _FILEEVENT._serialized_end=9998
  _FILEEVENT_OP._serialized_start=9948
  _FILEEVENT_OP._serialized_end=9998
  _FLUSH._serialized_start=10000
  _FLUSH._serialized_end=10099
  _FLUSH_CONSISTENCY._serialized_start=10054
  _FLUSH_CONSISTENCY._serialized_end=10099
  _OTLINKFILE._serialized_start=10101
  _OTLINKFILE._serialized_end=10191
  _OTLINKFILERESPONSE._serialized_start=10193
  _OTLINKFILERESPONSE._serialized_end=10261
  _AUTH._serialized_start=10263
  _AUTH._serialized_end=10305
  _VCRENTRY._serialized_start=10308
  _VCRENTRY._serialized_end=10471
  _VCRENTRY_DIRECTION._serialized_start=10443
  _VCRENTRY_DIRECTION._serialized_end=10471
  _STARTVCR._serialized_start=10473
  _STARTVCR._serialized_end=10483
  _READVCR._serialized_start=10485
  _READVCR._serialized_end=10494
  _VCRLOG._serialized_start=10496
  _VCRLOG._serialized_end=10560
  _EXECINFO._serialized_start=10562
  _EXECINFO._serialized_end=10605
  _DEBUG._serialized_start=10607
  _DEBUG._serialized_end=10628
  _FILEAUTHREQ._serialized_start=10630
  _FILEAUTHREQ._serialized_end=10705
  _MULTIFILEAUTHRES._serialized_start=10707
  _MULTIFILEAUTHRES._serialized_end=10818
  _FILEAUTHRES._serialized_start=10821
  _FILEAUTHRES._serialized_end=10959
  _LISTOBJECTS._serialized_start=10961
  _LISTOBJECTS._serialized_end=10990
  _LISTOBJECTSRESP._serialized_start=10992
  _LISTOBJECTSRESP._serialized_end=11026
  _DISCONNECT._serialized_start=11028
  _DISCONNECT._serialized_end=11055
  _SEND._serialized_start=11057
  _SEND._serialized_end=11077
  _RECV._serialized_start=11079
  _RECV._serialized_end=11099
  _CONNECT._serialized_start=11101
  _CONNECT._serialized_end=11139
  _HINT._serialized_start=11141
  _HINT._serialized_end=11161
  _PING._serialized_start=11163
  _PING._serialized_end=11169
  _PONG._serialized_start=11171
  _PONG._serialized_end=11177
  _HELLO._serialized_start=11179
  _HELLO._serialized_end=11235
  _GOODBYE._serialized_start=11237
  _GOODBYE._serialized_end=11246
  _CHECKCHANGES._serialized_start=11248
  _CHECKCHANGES._serialized_end=11262
  _ENSUREPACKAGES._serialized_start=11264
  _ENSUREPACKAGES._serialized_end=11322
  _START._serialized_start=11324
  _START._serialized_end=11331
  _DEBUGSTATUS._serialized_start=11333
  _DEBUGSTATUS._serialized_end=11392
  _STACKFRAME._serialized_start=11394
  _STACKFRAME._serialized_end=11438
  _CONTAINEDTEST._serialized_start=11440
  _CONTAINEDTEST._serialized_end=11509
  _TESTRESULT._serialized_start=11511
  _TESTRESULT._serialized_end=11588
  _TESTFAILURE._serialized_start=11590
  _TESTFAILURE._serialized_end=11632
  _RESIZETERM._serialized_start=11634
  _RESIZETERM._serialized_end=11674
  _SANETERM._serialized_start=11676
  _SANETERM._serialized_end=11686
  _LINTRESULTS._serialized_start=11688
  _LINTRESULTS._serialized_end=11735
  _LINTRESULT._serialized_start=11737
  _LINTRESULT._serialized_end=11806
  _OK._serialized_start=11808
  _OK._serialized_end=11812
  _MOVE._serialized_start=11814
  _MOVE._serialized_end=11854
  _FILES._serialized_start=11856
  _FILES._serialized_end=11889
  _STATRESULT._serialized_start=11891
  _STATRESULT._serialized_end=11998
  _FILE._serialized_start=12000
  _FILE._serialized_end=12103
  _FILE_TYPE._serialized_start=12069
  _FILE_TYPE._serialized_end=12103
  _TRANSFER._serialized_start=12105
  _TRANSFER._serialized_end=12127
  _TRANSFERSTART._serialized_start=12129
  _TRANSFERSTART._serialized_end=12172
  _TRANSFERCHUNK._serialized_start=12174
  _TRANSFERCHUNK._serialized_end=12218
  _TRANSFERCOMPLETE._serialized_start=12220
  _TRANSFERCOMPLETE._serialized_end=12265
  _CLEAR._serialized_start=12267
  _CLEAR._serialized_end=12274
  _TOAST._serialized_start=12276
  _TOAST._serialized_end=12297
  _PROTOCOLERROR._serialized_start=12299
  _PROTOCOLERROR._serialized_end=12328
  _REDIRECT._serialized_start=12330
  _REDIRECT._serialized_end=12353
  _ALWAYSON._serialized_start=12355
  _ALWAYSON._serialized_end=12381
  _RUNMAIN._serialized_start=12384
  _RUNMAIN._serialized_end=12520
  _RUNMAIN_RUNMODE._serialized_start=12490
  _RUNMAIN_RUNMODE._serialized_end=12520
  _OPENCHANNEL._serialized_start=12523
  _OPENCHANNEL._serialized_end=12676
  _OPENCHANNEL_ACTION._serialized_start=12622
  _OPENCHANNEL_ACTION._serialized_end=12676
  _OPENCHANNELRES._serialized_start=12679
  _OPENCHANNELRES._serialized_end=12811
  _OPENCHANNELRES_STATE._serialized_start=12766
  _OPENCHANNELRES_STATE._serialized_end=12811
  _CLOSECHANNEL._serialized_start=12813
  _CLOSECHANNEL._serialized_end=12933
  _CLOSECHANNEL_ACTION._serialized_start=12883
  _CLOSECHANNEL_ACTION._serialized_end=12933
  _CLOSECHANNELRES._serialized_start=12935
  _CLOSECHANNELRES._serialized_end=13059
  _CLOSECHANNELRES_STATUS._serialized_start=13011
  _CLOSECHANNELRES_STATUS._serialized_end=13059
  _CONTAINERSTATE._serialized_start=13061
  _CONTAINERSTATE._serialized_end=13150
  _CONTAINERSTATE_STATE._serialized_start=13121
  _CONTAINERSTATE_STATE._serialized_end=13150
  _PORTOPEN._serialized_start=13152
  _PORTOPEN._serialized_end=13234
  _PORTCLOSE._serialized_start=13236
  _PORTCLOSE._serialized_end=13300
  _OTFETCHREQUEST._serialized_start=13302
  _OTFETCHREQUEST._serialized_end=13358
  _OTFETCHRESPONSE._serialized_start=13360
  _OTFETCHRESPONSE._serialized_end=13409
  _OTTRANSFORMSELECTIONREQUEST._serialized_start=13411
  _OTTRANSFORMSELECTIONREQUEST._serialized_end=13518
  _OTTRANSFORMSELECTIONRESPONSE._serialized_start=13520
  _OTTRANSFORMSELECTIONRESPONSE._serialized_end=13605
  _OTPACKET._serialized_start=13608
  _OTPACKET._serialized_end=13858
  _OTPACKET_AUTHOR._serialized_start=13823
  _OTPACKET_AUTHOR._serialized_end=13858
  _OTOPCOMPONENT._serialized_start=13860
  _OTOPCOMPONENT._serialized_end=13942
  _OTSTATUS._serialized_start=13944
  _OTSTATUS._serialized_end=14052
  _OTCURSOR._serialized_start=14054
  _OTCURSOR._serialized_end=14165
  _CHATMESSAGE._serialized_start=14167
  _CHATMESSAGE._serialized_end=14212
  _CHATTYPING._serialized_start=14214
  _CHATTYPING._serialized_end=14260
  _USER._serialized_start=14262
  _USER._serialized_end=14389
  _ROSTER._serialized_start=14391
  _ROSTER._serialized_end=14456
  _OPENFILE._serialized_start=14458
  _OPENFILE._serialized_end=14482
  _FILEOPENED._serialized_start=14484
  _FILEOPENED._serialized_end=14590
  _REPLSPACEAPIOPENFILE._serialized_start=14592
  _REPLSPACEAPIOPENFILE._serialized_end=14665
  _REPLSPACEAPICLOSEFILE._serialized_start=14667
  _REPLSPACEAPICLOSEFILE._serialized_end=14719
  _REPLSPACEAPIGETGITHUBTOKEN._serialized_start=14721
  _REPLSPACEAPIGETGITHUBTOKEN._serialized_end=14764
  _REPLSPACEAPIGITHUBTOKEN._serialized_start=14766
  _REPLSPACEAPIGITHUBTOKEN._serialized_end=14821
  _FOCUSED._serialized_start=14823
  _FOCUSED._serialized_end=14832
  _UPDATESESSIONTIMESTAMP._serialized_start=14834
  _UPDATESESSIONTIMESTAMP._serialized_end=14858
  _SESSIONTIMESTAMPUPDATED._serialized_start=14860
  _SESSIONTIMESTAMPUPDATED._serialized_end=14949
  _FOLLOWUSER._serialized_start=14951
  _FOLLOWUSER._serialized_end=14980
  _UNFOLLOWUSER._serialized_start=14982
  _UNFOLLOWUSER._serialized_end=15013
  _EXEC._serialized_start=15016
  _EXEC._serialized_end=15267
  _EXEC_ENVENTRY._serialized_start=9658
  _EXEC_ENVENTRY._serialized_end=9700
  _EXEC_LIFECYCLE._serialized_start=15213
  _EXEC_LIFECYCLE._serialized_end=15267
  _PACKAGE._serialized_start=15270
  _PACKAGE._serialized_end=15507
  _PACKAGESETPACKAGERREQUEST._serialized_start=15509
  _PACKAGESETPACKAGERREQUEST._serialized_end=15556
  _PACKAGESETPACKAGERRESPONSE._serialized_start=15558
  _PACKAGESETPACKAGERRESPONSE._serialized_end=15606
  _PACKAGESEARCH._serialized_start=15608
  _PACKAGESEARCH._serialized_end=15638
  _PACKAGESEARCHRESP._serialized_start=15640
  _PACKAGESEARCHRESP._serialized_end=15690
  _PACKAGEINFO._serialized_start=15692
  _PACKAGEINFO._serialized_end=15732
  _PACKAGEINFORESP._serialized_start=15734
  _PACKAGEINFORESP._serialized_end=15778
  _PACKAGEADD._serialized_start=15780
  _PACKAGEADD._serialized_end=15820
  _PACKAGEREMOVE._serialized_start=15822
  _PACKAGEREMOVE._serialized_end=15865
  _PACKAGEINSTALL._serialized_start=15867
  _PACKAGEINSTALL._serialized_end=15904
  _PACKAGELISTSPECFILE._serialized_start=15906
  _PACKAGELISTSPECFILE._serialized_end=15927
  _PACKAGELISTSPECFILERESP._serialized_start=15929
  _PACKAGELISTSPECFILERESP._serialized_end=15982
  _PACKAGECACHESAVE._serialized_start=15984
  _PACKAGECACHESAVE._serialized_end=16002
  _CHATSCROLLBACK._serialized_start=16004
  _CHATSCROLLBACK._serialized_end=16058
  _METRICS._serialized_start=16060
  _METRICS._serialized_end=16103
  _PPROFREQUEST._serialized_start=16106
  _PPROFREQUEST._serialized_end=16471
  _PPROFALLOCSPROFILEREQUEST._serialized_start=16473
  _PPROFALLOCSPROFILEREQUEST._serialized_end=16515
  _PPROFBLOCKPROFILEREQUEST._serialized_start=16517
  _PPROFBLOCKPROFILEREQUEST._serialized_end=16558
  _PPROFCPUPROFILEREQUEST._serialized_start=16560
  _PPROFCPUPROFILEREQUEST._serialized_end=16601
  _PPROFHEAPPROFILEREQUEST._serialized_start=16603
  _PPROFHEAPPROFILEREQUEST._serialized_end=16655
  _PPROFMUTEXPROFILEREQUEST._serialized_start=16657
  _PPROFMUTEXPROFILEREQUEST._serialized_end=16698
  _PPROFRESPONSE._serialized_start=16700
  _PPROFRESPONSE._serialized_end=16744
  _PTYCONFIG._serialized_start=16746
  _PTYCONFIG._serialized_end=16775
  _DEBUGMAIN._serialized_start=16777
  _DEBUGMAIN._serialized_end=16861
  _DEBUGMAINREPLY._serialized_start=16863
  _DEBUGMAINREPLY._serialized_end=16964
  _DEBUGMAINREPLY_PROTOCOL._serialized_start=16945
  _DEBUGMAINREPLY_PROTOCOL._serialized_end=16964
  _DEBUGSTATE._serialized_start=16966
  _DEBUGSTATE._serialized_end=17022
  _DEBUGINPUT._serialized_start=17024
  _DEBUGINPUT._serialized_end=17104
  _DEBUGOUTPUT._serialized_start=17106
  _DEBUGOUTPUT._serialized_end=17189
  _DEBUGSTOP._serialized_start=17191
  _DEBUGSTOP._serialized_end=17219
  _DEBUGLEAVE._serialized_start=17221
  _DEBUGLEAVE._serialized_end=17250
  _DEBUGSESSIONS._serialized_start=17253
  _DEBUGSESSIONS._serialized_end=17381
  _DEBUGSESSIONS_SESSIONSENTRY._serialized_start=17322
  _DEBUGSESSIONS_SESSIONSENTRY._serialized_end=17381
  _DOTREPLITGETREQUEST._serialized_start=17383
  _DOTREPLITGETREQUEST._serialized_end=17404
  _DOTREPLITGETRESPONSE._serialized_start=17406
  _DOTREPLITGETRESPONSE._serialized_end=17463
  _RUNCONFIGGETREQUEST._serialized_start=17465
  _RUNCONFIGGETREQUEST._serialized_end=17486
  _RUNCONFIGGETRESPONSE._serialized_start=17489
  _RUNCONFIGGETRESPONSE._serialized_end=17666
  _RUNCONFIGGETRESPONSE_RUN._serialized_start=17599
  _RUNCONFIGGETRESPONSE_RUN._serialized_end=17656
  _DOTREPLITUPDATEOP._serialized_start=17668
  _DOTREPLITUPDATEOP._serialized_end=17728
  _DOTREPLITUPDATEREQUEST._serialized_start=17730
  _DOTREPLITUPDATEREQUEST._serialized_end=17791
  _DOTREPLITUPDATERESPONSE._serialized_start=17793
  _DOTREPLITUPDATERESPONSE._serialized_end=17818
  _DEBUGADDBREAKPOINTREQUEST._serialized_start=17821
  _DEBUGADDBREAKPOINTREQUEST._serialized_end=17954
  _DEBUGUPDATEBREAKPOINTREQUEST._serialized_start=17956
  _DEBUGUPDATEBREAKPOINTREQUEST._serialized_end=18028
  _DEBUGREMOVEBREAKPOINTREQUEST._serialized_start=18030
  _DEBUGREMOVEBREAKPOINTREQUEST._serialized_end=18082
  _DEBUGBREAKPOINTEVENT._serialized_start=18084
  _DEBUGBREAKPOINTEVENT._serialized_end=18185
  _DEBUGBREAKPOINT._serialized_start=18188
  _DEBUGBREAKPOINT._serialized_end=18319
  _DOTREPLIT._serialized_start=18322
  _DOTREPLIT._serialized_end=19250
  _DOTREPLIT_LANGUAGESENTRY._serialized_start=19134
  _DOTREPLIT_LANGUAGESENTRY._serialized_end=19206
  _DOTREPLIT_ENVENTRY._serialized_start=9658
  _DOTREPLIT_ENVENTRY._serialized_end=9700
  _DOTREPLITENVVAR._serialized_start=19252
  _DOTREPLITENVVAR._serialized_end=19297
  _DOTREPLITPORT._serialized_start=19299
  _DOTREPLITPORT._serialized_end=19355
  _DOTREPLITHINT._serialized_start=19357
  _DOTREPLITHINT._serialized_end=19404
  _GITHUBIMPORTCONFIG._serialized_start=19406
  _GITHUBIMPORTCONFIG._serialized_end=19449
  _DEPLOYMENTCONFIG._serialized_start=19452
  _DEPLOYMENTCONFIG._serialized_end=19651
  _DEPLOYMENTCONFIG_TARGET._serialized_start=19608
  _DEPLOYMENTCONFIG_TARGET._serialized_end=19651
  _EXTENSIONCONFIG._serialized_start=19653
  _EXTENSIONCONFIG._serialized_end=19759
  _NIXCONFIG._serialized_start=19761
  _NIXCONFIG._serialized_end=19789
  _HOSTINGCONFIG._serialized_start=19791
  _HOSTINGCONFIG._serialized_end=19840
  _AUTHCONFIG._serialized_start=19843
  _AUTHCONFIG._serialized_end=19981
  _DOTREPLITINTERP._serialized_start=19983
  _DOTREPLITINTERP._serialized_end=20044
  _DOTREPLITLANGUAGE._serialized_start=20046
  _DOTREPLITLANGUAGE._serialized_end=20149
  _LANGUAGESERVERCONFIG._serialized_start=20151
  _LANGUAGESERVERCONFIG._serialized_end=20268
  _DOTREPLITPACKAGER._serialized_start=20271
  _DOTREPLITPACKAGER._serialized_end=20528
  _DOTREPLITPACKAGER_ENVENTRY._serialized_start=9658
  _DOTREPLITPACKAGER_ENVENTRY._serialized_end=9700
  _DOTREPLITPACKAGERFEATURES._serialized_start=20530
  _DOTREPLITPACKAGERFEATURES._serialized_end=20629
  _DOTREPLITUNITTEST._serialized_start=20631
  _DOTREPLITUNITTEST._serialized_end=20668
  _DEBUGGERCONFIG._serialized_start=20671
  _DEBUGGERCONFIG._serialized_end=21075
  _COMPILECONFIG._serialized_start=21077
  _COMPILECONFIG._serialized_end=21158
  _DAPCONFIG._serialized_start=21161
  _DAPCONFIG._serialized_end=21408
  _TIMETRAVELCONFIG._serialized_start=21410
  _TIMETRAVELCONFIG._serialized_end=21486
  _DAPINTEGRATEDADAPTERCONFIG._serialized_start=21488
  _DAPINTEGRATEDADAPTERCONFIG._serialized_end=21539
  _PROXYGOINGAWAY._serialized_start=21541
  _PROXYGOINGAWAY._serialized_end=21557
  _FIREWALLDENIED._serialized_start=21559
  _FIREWALLDENIED._serialized_end=21575
  _REPLLOGMESSAGE._serialized_start=21577
  _REPLLOGMESSAGE._serialized_end=21691
  _USEREVENT._serialized_start=21693
  _USEREVENT._serialized_end=21784
  _NIXMODULESGETREQUEST._serialized_start=21786
  _NIXMODULESGETREQUEST._serialized_end=21808
  _NIXMODULESGETRESPONSE._serialized_start=21810
  _NIXMODULESGETRESPONSE._serialized_end=21866
  _NIXMODULE._serialized_start=21869
  _NIXMODULE._serialized_end=22109
  _NIXMODULESCHANGED._serialized_start=22111
  _NIXMODULESCHANGED._serialized_end=22163
  _NIXMODULESBUILDREQUEST._serialized_start=22165
  _NIXMODULESBUILDREQUEST._serialized_end=22189
  _TOOLCHAINGETREQUEST._serialized_start=22191
  _TOOLCHAINGETREQUEST._serialized_end=22212
  _TOOLCHAINCONFIGS._serialized_start=22215
  _TOOLCHAINCONFIGS._serialized_end=22415
  _TOOLCHAINGETRESPONSE._serialized_start=22417
  _TOOLCHAINGETRESPONSE._serialized_end=22479
  _TOOLCHAINCHANGED._serialized_start=22481
  _TOOLCHAINCHANGED._serialized_end=22539
  _RUNOPTION._serialized_start=22541
  _RUNOPTION._serialized_end=22658
  _DEBUGGEROPTION._serialized_start=22660
  _DEBUGGEROPTION._serialized_end=22782
  _LANGUAGESERVEROPTION._serialized_start=22785
  _LANGUAGESERVEROPTION._serialized_end=22937
  _FILETYPEATTRS._serialized_start=22939
  _FILETYPEATTRS._serialized_end=23010
  _PACKAGEROPTION._serialized_start=23013
  _PACKAGEROPTION._serialized_end=23168
  _REPLDOMAINDOUBLEDASH._serialized_start=23170
  _REPLDOMAINDOUBLEDASH._serialized_end=23236
  _REPLDOMAINDOTS._serialized_start=23238
  _REPLDOMAINDOTS._serialized_end=23298
  _REPLDOMAINSINGLEDOMAIN._serialized_start=23300
  _REPLDOMAINSINGLEDOMAIN._serialized_end=23354
  _REPLDOMAINID._serialized_start=23356
  _REPLDOMAINID._serialized_end=23398
  _REPLDOMAIN._serialized_start=23401
  _REPLDOMAIN._serialized_end=23611
  _REPLTOKEN._serialized_start=23614
  _REPLTOKEN._serialized_end=24439
  _REPLTOKEN_CLASSROOMMETADATA._serialized_start=24247
  _REPLTOKEN_CLASSROOMMETADATA._serialized_end=24296
  _REPLTOKEN_REPLID._serialized_start=24298
  _REPLTOKEN_REPLID._serialized_end=24338
  _REPLTOKEN_PRESENCED._serialized_start=24340
  _REPLTOKEN_PRESENCED._serialized_end=24389
  _REPLTOKEN_WIREFORMAT._serialized_start=24391
  _REPLTOKEN_WIREFORMAT._serialized_end=24427
  _TLSCERTIFICATE._serialized_start=24441
  _TLSCERTIFICATE._serialized_end=24487
  _REPLTRANSFER._serialized_start=24490
  _REPLTRANSFER._serialized_end=24707
  _ALLOWREPLREQUEST._serialized_start=24709
  _ALLOWREPLREQUEST._serialized_end=24768
  _CLUSTERMETADATA._serialized_start=24770
  _CLUSTERMETADATA._serialized_end=24866
  _EVICTREPLREQUEST._serialized_start=24868
  _EVICTREPLREQUEST._serialized_end=24976
  _EVICTREPLRESPONSE._serialized_start=24978
  _EVICTREPLRESPONSE._serialized_end=25038
  _GOVALSIGNINGAUTHORITY._serialized_start=25040
  _GOVALSIGNINGAUTHORITY._serialized_end=25162
  _CERTIFICATECLAIM._serialized_start=25164
  _CERTIFICATECLAIM._serialized_end=25276
  _GOVALCERT._serialized_start=25279
  _GOVALCERT._serialized_end=25430
  _GOVALTOKEN._serialized_start=25433
  _GOVALTOKEN._serialized_end=25637
  _GOVALREPLIDENTITY._serialized_start=25640
  _GOVALREPLIDENTITY._serialized_end=25813
  _LORE._serialized_start=25816
  _LORE._serialized_end=27115
  _LORE_LORECOMMAND._serialized_start=25825
  _LORE_LORECOMMAND._serialized_end=26135
  _LORE_CLUSTERTRANSFER._serialized_start=26138
  _LORE_CLUSTERTRANSFER._serialized_end=26267
  _LORE_SOFTTAKEDOWN._serialized_start=26269
  _LORE_SOFTTAKEDOWN._serialized_end=26323
  _LORE_TAKEDOWN._serialized_start=26325
  _LORE_TAKEDOWN._serialized_end=26351
  _LORE_GOVALCOMMAND._serialized_start=26354
  _LORE_GOVALCOMMAND._serialized_end=26729
  _LORE_PARTIALUPDATEMETADATA._serialized_start=26731
  _LORE_PARTIALUPDATEMETADATA._serialized_end=26845
  _LORE_MULTIGOVALCOMMAND._serialized_start=26847
  _LORE_MULTIGOVALCOMMAND._serialized_end=26929
  _LORE_KILLREPL._serialized_start=26931
  _LORE_KILLREPL._serialized_end=26957
  _LORE_RESTORE._serialized_start=26959
  _LORE_RESTORE._serialized_end=27007
  _LORE_UPDATESOURCEREPL._serialized_start=27009
  _LORE_UPDATESOURCEREPL._serialized_end=27065
  _LORE_UPDATEREPLFLAGS._serialized_start=27067
  _LORE_UPDATEREPLFLAGS._serialized_end=27115
  _FEATURES._serialized_start=27118
  _FEATURES._serialized_end=27262
  _FEATURES_GPU._serialized_start=27130
  _FEATURES_GPU._serialized_end=27135
  _FEATURES_BOOSTED._serialized_start=27137
  _FEATURES_BOOSTED._serialized_end=27146
  _FEATURES_FEATURE._serialized_start=27148
  _FEATURES_FEATURE._serialized_end=27262
  _REPL._serialized_start=27265
  _REPL._serialized_end=28399
  _REPL_BUCKETS._serialized_start=27273
  _REPL_BUCKETS._serialized_end=27319
  _REPL_REPL._serialized_start=27322
  _REPL_REPL._serialized_end=27510
  _REPL_USERID._serialized_start=27512
  _REPL_USERID._serialized_end=27576
  _REPL_RESOURCELIMITS._serialized_start=27579
  _REPL_RESOURCELIMITS._serialized_end=27817
  _REPL_RESOURCELIMITS_CACHABILITY._serialized_start=27774
  _REPL_RESOURCELIMITS_CACHABILITY._serialized_end=27817
  _REPL_PERMISSIONS._serialized_start=27819
  _REPL_PERMISSIONS._serialized_end=27856
  _REPL_METADATA._serialized_start=27859
  _REPL_METADATA._serialized_end=28194
  _REPL_BUILDINFO._serialized_start=28196
  _REPL_BUILDINFO._serialized_end=28280
  _REPL_ENVIRONMENT._serialized_start=28282
  _REPL_ENVIRONMENT._serialized_end=28328
  _REPL_PERSISTENCE._serialized_start=28330
  _REPL_PERSISTENCE._serialized_end=28399
  _PRIVATEREPLSPOWERUP._serialized_start=28401
  _PRIVATEREPLSPOWERUP._serialized_end=28439
  _GHOSTWRITERPOWERUP._serialized_start=28441
  _GHOSTWRITERPOWERUP._serialized_end=28478
  _CONNECTIVITYPOWERUP._serialized_start=28480
  _CONNECTIVITYPOWERUP._serialized_end=28518
  _POWERUP._serialized_start=28521
  _POWERUP._serialized_end=28731
  _USERPOWERUPS._serialized_start=28733
  _USERPOWERUPS._serialized_end=28813
# @@protoc_insertion_point(module_scope)



from .exceptions import GovalException, ConnectionMetadataExeption
from .channel import Channel, Channel0
from .proto import api_pb2 as api

from typing import Optional, TypedDict
import websocket
import asyncio
import time
import enum


class ConnectionState(enum.IntEnum):
    CONNECTING = 0
    CONNECTED = 1
    DISCONNECTED = 2


class ConnectionMetadata(TypedDict):
    token: str
    gurl: str
    conmanURL: str
    message: Optional[str]


# TODO: Handle closing the client
# TODO: Error on action when client is disconnected
# TODO: Handle redirects


class Client:
    _websocket: websocket.WebSocket
    wait_messages_task: asyncio.Task[None]

    channels: dict[int, Channel]
    chan0: Channel0

    state: ConnectionState
    last_ping: float

    def __init__(self):
        self.channels = {}
        self.last_ping = 0
        self.state = ConnectionState.DISCONNECTED

    def _send(self, cmd: api.Command):
        self._websocket.send_binary(cmd.SerializePartialToString())

    def get_close_channel(self, id: int):
        async def close():
            await self.chan0.request(
                api.Command(
                    closeChan=api.CloseChannel(action=api.CloseChannel.Action.TRY_CLOSE)
                )
            )

        return close

    async def start(self, metadata: ConnectionMetadata):
        if error := metadata.get("message"):
            raise ConnectionMetadataExeption(error)

        self.state = ConnectionState.CONNECTING

        self._websocket = websocket.create_connection(
            metadata["gurl"] + "/wsv2/" + metadata["token"]
        )

        self.chan0 = Channel0(self._send, 0, "chan0", "chan0")
        self.channels[0] = self.chan0

        self.wait_messages_task = asyncio.get_event_loop().create_task(
            self.wait_messages()
        )

        self.state = ConnectionState.CONNECTED

    async def open_channel(
        self,
        service: str,
        name: Optional[str] = None,
        action: api.OpenChannel.Action.ValueType = api.OpenChannel.Action.CREATE,
    ) -> Channel:
        cmd = api.Command(openChan=api.OpenChannel(service=service, action=action))

        if name:
            cmd.openChan.name = name
        res = await self.chan0.request(cmd)

        if not res.openChanRes:
            raise GovalException(f"Expected openChanRes message got {res}")

        if res.openChanRes.error:
            raise GovalException(
                f"Got error {res.openChanRes.error} while opening channel"
            )

        channel = Channel(
            self._send,
            res.openChanRes.id,
            service,
            name,
            self.get_close_channel(res.openChanRes.id),
        )

        self.channels[res.openChanRes.id] = channel
        return channel

    async def wait_messages(self):
        while True:
            result: bytes = await asyncio.get_event_loop().run_in_executor(
                None, self._websocket.recv
            )  # type: ignore
            cmd = api.Command()
            cmd.ParseFromString(result)

            channel = cmd.channel or 0
            await self.channels[channel]._on_message(cmd)

            if self.last_ping + 0.2 < time.time():
                await asyncio.get_event_loop().run_in_executor(
                    None, self._websocket.ping
                )

            await asyncio.sleep(0)

    def close(self):
        raise NotImplementedError("WIP")
